<?php

add_action( 'wp_update_nav_menu_item', 'VM_custom_nav_update', 10, 3 );
function VM_custom_nav_update(
	/** @noinspection PhpUnusedParameterInspection */
	$menu_id, $menu_item_db_id = 0, /** @noinspection PhpUnusedParameterInspection */
	$args
) {
	if ( isset( $_REQUEST['menu-item-custom'] ) ) {
		if ( is_array( $_REQUEST['menu-item-custom'] ) ) {
			$custom_value = $_REQUEST['menu-item-custom'][ $menu_item_db_id ];
			update_post_meta( $menu_item_db_id, '_menu_item_custom', $custom_value );
		}
	}
	if ( isset( $_REQUEST['menu-item-custom-img-icon'] ) ) {
		if ( is_array( $_REQUEST['menu-item-custom-img-icon'] ) ) {
			$custom_value_img = $_REQUEST['menu-item-custom-img-icon'][ $menu_item_db_id ];
			update_post_meta( $menu_item_db_id, '_menu_item_custom_img_icon', $custom_value_img );
		}
	}
	if ( isset( $_REQUEST['menu-item-custom-stay-active-dropDown'] ) ) {
		if ( is_array( $_REQUEST['menu-item-custom-stay-active-dropDown'] ) ) {
			$custom_value_Active_DropDown = $_REQUEST['menu-item-custom-stay-active-dropDown'][ $menu_item_db_id ];
			update_post_meta( $menu_item_db_id, '_menu_item_custom_stay_active_dropDown', $custom_value_Active_DropDown );
		}
	}
}

/*
 * Adds value of new field to $item object that will be passed to     Walker_Nav_Menu_Edit_Custom
 */
add_filter( 'wp_setup_nav_menu_item', 'VM_custom_nav_item' );
function VM_custom_nav_item( $menu_item ) {
	$menu_item->VM_customIcon             = get_post_meta( $menu_item->ID, '_menu_item_custom', true );
	$menu_item->VM_customIconImg          = get_post_meta( $menu_item->ID, '_menu_item_custom_img_icon', true );
	$menu_item->VM_custom_Active_DropDown = get_post_meta( $menu_item->ID, '_menu_item_custom_stay_active_dropDown', true );

	return $menu_item;
}

add_filter( 'wp_edit_nav_menu_walker', 'VM_custom_nav_edit_walker', 10, 2 );
function VM_custom_nav_edit_walker(
	/** @noinspection PhpUnusedParameterInspection */
	$walker, /** @noinspection PhpUnusedParameterInspection */
	$menu_id
) {
	return 'VM_Walker_Nav_Menu_Edit_Custom';
}

/**
 * Copied from Walker_Nav_Menu_Edit class in core
 *
 * Create HTML list of nav menu input items.
 *
 * @package WordPress
 * @since 3.0.0
 * @uses Walker_Nav_Menu
 */
class VM_Walker_Nav_Menu_Edit_Custom extends Walker_Nav_Menu {
	/**
	 * @see Walker_Nav_Menu::start_lvl()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 * @param int $depth
	 * @param array $args
	 */
	function start_lvl( &$output, $depth = 0, $args = array() ) {
	}

	/**
	 * @see Walker_Nav_Menu::end_lvl()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 * @param int $depth
	 * @param array $args
	 */
	function end_lvl( &$output, $depth = 0, $args = array() ) {
	}

	/**
	 * @see Walker::start_el()
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item Menu item data object.
	 * @param int $depth Depth of menu item. Used for padding.
	 * @param array|object $args
	 * @param int $id
	 */
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $_wp_nav_menu_max_depth;
		$_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

//		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		ob_start();
		$item_id      = esc_attr( $item->ID );
		$removed_args = array(
			'action',
			'customlink-tab',
			'edit-menu-item',
			'menu-item',
			'page-tab',
			'_wpnonce',
		);

		$original_title = '';
		if ( 'taxonomy' == $item->type ) {
			$original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
			if ( is_wp_error( $original_title ) ) {
				$original_title = false;
			}
		} elseif ( 'post_type' == $item->type ) {
			$original_object = get_post( $item->object_id );
			$original_title  = $original_object->post_title;
		}

		$classes = array(
			'menu-item menu-item-depth-' . $depth,
			'menu-item-' . esc_attr( $item->object ),
			'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive' ),
		);

		$title = $item->title;

		if ( ! empty( $item->_invalid ) ) {
			$classes[] = 'menu-item-invalid';
			/* translators: %s: title of menu item which is invalid */
			$title = sprintf( __( '%s (Invalid)' ), $item->title );
		} elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
			$classes[] = 'pending';
			/* translators: %s: title of menu item in draft status */
			$title = sprintf( __( '%s (Pending)' ), $item->title );
		}

		$title = empty( $item->label ) ? $title : $item->label;

		?>
	<li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode( ' ', $classes ); ?>">
		<dl class="menu-item-bar">
			<dt class="menu-item-handle">
				<span class="item-title"><?php echo esc_html( $title ); ?></span>
                <span class="item-controls">
                    <span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
                    <span class="item-order hide-if-js">
                        <a href="<?php
                        echo wp_nonce_url(
	                        add_query_arg(
		                        array(
			                        'action'    => 'move-up-menu-item',
			                        'menu-item' => $item_id,
		                        ),
		                        remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) )
	                        ),
	                        'move-menu_item'
                        );
                        ?>" class="item-move-up"><abbr title="<?php esc_attr_e( 'Move up' ); ?>">&#8593;</abbr></a>
                        |
                        <a href="<?php
                        echo wp_nonce_url(
	                        add_query_arg(
		                        array(
			                        'action'    => 'move-down-menu-item',
			                        'menu-item' => $item_id,
		                        ),
		                        remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) )
	                        ),
	                        'move-menu_item'
                        );
                        ?>" class="item-move-down"><abbr title="<?php esc_attr_e( 'Move down' ); ?>">&#8595;</abbr></a>
                    </span>
                    <a class="item-edit" id="edit-<?php echo $item_id; ?>" title="<?php esc_attr_e( 'Edit Menu Item' ); ?>" href="<?php
                    echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
                    ?>"><?php _e( 'Edit Menu Item' ); ?></a>
                </span>
			</dt>
		</dl>

		<div class="menu-item-settings" id="menu-item-settings-<?php echo $item_id; ?>">
			<?php if ( 'custom' == $item->type ) : ?>
				<p class="field-url description description-wide">
					<label for="edit-menu-item-url-<?php echo $item_id; ?>">
						<?php _e( 'URL' ); ?><br/>
						<input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>"/>
					</label>
				</p>
			<?php endif; ?>
			<p class="description description-thin">
				<label for="edit-menu-item-title-<?php echo $item_id; ?>">
					<?php _e( 'Navigation Label' ); ?><br/>
					<input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>"/>
				</label>
			</p>

			<p class="description description-thin">
				<label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
					<?php _e( 'Title Attribute' ); ?><br/>
					<input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>"/>
				</label>
			</p>

			<p class="field-link-target description">
				<label for="edit-menu-item-target-<?php echo $item_id; ?>">
					<input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
					<?php _e( 'Open link in a new window/tab' ); ?>
				</label>
			</p>

			<p class="field-css-classes description description-thin">
				<label for="edit-menu-item-classes-<?php echo $item_id; ?>">
					<?php _e( 'CSS Classes (optional)' ); ?><br/>
					<input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode( ' ', $item->classes ) ); ?>"/>
				</label>
			</p>

			<p class="field-xfn description description-thin">
				<label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
					<?php _e( 'Link Relationship (XFN)' ); ?><br/>
					<input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>"/>
				</label>
			</p>

			<p class="field-description description description-wide">
				<label for="edit-menu-item-description-<?php echo $item_id; ?>">
					<?php _e( 'Description' ); ?><br/>
					<textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
					<span class="description"><?php _e( 'The description will be displayed in the menu if the current theme supports it.' ); ?></span>
				</label>
			</p>
			<?php
			/*
			 * This is the added field
			 */
			if ( $depth === 0 ) {
				$VM_customMenuIconHide = 'block';
			} else {
				$VM_customMenuIconHide = 'none';
			}
			?>

			<div class="field-custom description description-wide" style="display: <?php echo $VM_customMenuIconHide; ?>">
				<label for="edit-menu-item-custom-<?php echo $item_id; ?>">
					<?php _e( 'Font Awesome Icon' ); ?><br/>
					<table style="width: 100%">
						<tr class="iconAppendRemove">
							<td>
								<select name="menu-item-custom[<?php echo $item_id; ?>]" id="edit-menu-item-custom-<?php echo $item_id; ?>" class="widefat code edit-menu-item-custom">
									<option <?php selected( $item->VM_customIcon, '' ) ?> value=""></option>
									<option <?php selected( $item->VM_customIcon, 'fa-500px' ) ?> value='fa-500px'>500px</option>
									<option <?php selected( $item->VM_customIcon, 'fa-adjust' ) ?> value='fa-adjust'>adjust</option>
									<option <?php selected( $item->VM_customIcon, 'fa-adn' ) ?> value='fa-adn'>adn</option>
									<option <?php selected( $item->VM_customIcon, 'fa-align-center' ) ?> value='fa-align-center'>align-center</option>
									<option <?php selected( $item->VM_customIcon, 'fa-align-justify' ) ?> value='fa-align-justify'>align-justify</option>
									<option <?php selected( $item->VM_customIcon, 'fa-align-left' ) ?> value='fa-align-left'>align-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-align-right' ) ?> value='fa-align-right'>align-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-amazon' ) ?> value='fa-amazon'>amazon</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ambulance' ) ?> value='fa-ambulance'>ambulance</option>
									<option <?php selected( $item->VM_customIcon, 'fa-anchor' ) ?> value='fa-anchor'>anchor</option>
									<option <?php selected( $item->VM_customIcon, 'fa-android' ) ?> value='fa-android'>android</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angellist' ) ?> value='fa-angellist'>angellist</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-double-down' ) ?> value='fa-angle-double-down'>angle-double-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-double-left' ) ?> value='fa-angle-double-left'>angle-double-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-double-right' ) ?> value='fa-angle-double-right'>angle-double-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-double-up' ) ?> value='fa-angle-double-up'>angle-double-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-down' ) ?> value='fa-angle-down'>angle-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-left' ) ?> value='fa-angle-left'>angle-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-right' ) ?> value='fa-angle-right'>angle-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-angle-up' ) ?> value='fa-angle-up'>angle-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-apple' ) ?> value='fa-apple'>apple</option>
									<option <?php selected( $item->VM_customIcon, 'fa-archive' ) ?> value='fa-archive'>archive</option>
									<option <?php selected( $item->VM_customIcon, 'fa-area-chart' ) ?> value='fa-area-chart'>area-chart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-down' ) ?> value='fa-arrow-circle-down'>arrow-circle-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-left' ) ?> value='fa-arrow-circle-left'>arrow-circle-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-o-down' ) ?> value='fa-arrow-circle-o-down'>arrow-circle-o-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-o-left' ) ?> value='fa-arrow-circle-o-left'>arrow-circle-o-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-o-right' ) ?> value='fa-arrow-circle-o-right'>arrow-circle-o-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-o-up' ) ?> value='fa-arrow-circle-o-up'>arrow-circle-o-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-right' ) ?> value='fa-arrow-circle-right'>arrow-circle-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-circle-up' ) ?> value='fa-arrow-circle-up'>arrow-circle-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-down' ) ?> value='fa-arrow-down'>arrow-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-left' ) ?> value='fa-arrow-left'>arrow-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-right' ) ?> value='fa-arrow-right'>arrow-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrow-up' ) ?> value='fa-arrow-up'>arrow-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrows' ) ?> value='fa-arrows'>arrows</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrows-alt' ) ?> value='fa-arrows-alt'>arrows-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrows-h' ) ?> value='fa-arrows-h'>arrows-h</option>
									<option <?php selected( $item->VM_customIcon, 'fa-arrows-v' ) ?> value='fa-arrows-v'>arrows-v</option>
									<option <?php selected( $item->VM_customIcon, 'fa-asterisk' ) ?> value='fa-asterisk'>asterisk</option>
									<option <?php selected( $item->VM_customIcon, 'fa-at' ) ?> value='fa-at'>at</option>
									<option <?php selected( $item->VM_customIcon, 'fa-automobile' ) ?> value='fa-automobile'>automobile</option>
									<option <?php selected( $item->VM_customIcon, 'fa-backward' ) ?> value='fa-backward'>backward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-balance-scale' ) ?> value='fa-balance-scale'>balance-scale</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ban' ) ?> value='fa-ban'>ban</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bank' ) ?> value='fa-bank'>bank</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bar-chart' ) ?> value='fa-bar-chart'>bar-chart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bar-chart-o' ) ?> value='fa-bar-chart-o'>bar-chart-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-barcode' ) ?> value='fa-barcode'>barcode</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bars' ) ?> value='fa-bars'>bars</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-0' ) ?> value='fa-battery-0'>battery-0</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-1' ) ?> value='fa-battery-1'>battery-1</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-2' ) ?> value='fa-battery-2'>battery-2</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-3' ) ?> value='fa-battery-3'>battery-3</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-4' ) ?> value='fa-battery-4'>battery-4</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-empty' ) ?> value='fa-battery-empty'>battery-empty</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-full' ) ?> value='fa-battery-full'>battery-full</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-half' ) ?> value='fa-battery-half'>battery-half</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-quarter' ) ?> value='fa-battery-quarter'>battery-quarter</option>
									<option <?php selected( $item->VM_customIcon, 'fa-battery-three-quarters' ) ?> value='fa-battery-three-quarters'>battery-three-quarters</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bed' ) ?> value='fa-bed'>bed</option>
									<option <?php selected( $item->VM_customIcon, 'fa-beer' ) ?> value='fa-beer'>beer</option>
									<option <?php selected( $item->VM_customIcon, 'fa-behance' ) ?> value='fa-behance'>behance</option>
									<option <?php selected( $item->VM_customIcon, 'fa-behance-square' ) ?> value='fa-behance-square'>behance-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bell' ) ?> value='fa-bell'>bell</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bell-o' ) ?> value='fa-bell-o'>bell-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bell-slash' ) ?> value='fa-bell-slash'>bell-slash</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bell-slash-o' ) ?> value='fa-bell-slash-o'>bell-slash-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bicycle' ) ?> value='fa-bicycle'>bicycle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-binoculars' ) ?> value='fa-binoculars'>binoculars</option>
									<option <?php selected( $item->VM_customIcon, 'fa-birthday-cake' ) ?> value='fa-birthday-cake'>birthday-cake</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bitbucket' ) ?> value='fa-bitbucket'>bitbucket</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bitbucket-square' ) ?> value='fa-bitbucket-square'>bitbucket-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bitcoin' ) ?> value='fa-bitcoin'>bitcoin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-black-tie' ) ?> value='fa-black-tie'>black-tie</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bold' ) ?> value='fa-bold'>bold</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bolt' ) ?> value='fa-bolt'>bolt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bomb' ) ?> value='fa-bomb'>bomb</option>
									<option <?php selected( $item->VM_customIcon, 'fa-book' ) ?> value='fa-book'>book</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bookmark' ) ?> value='fa-bookmark'>bookmark</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bookmark-o' ) ?> value='fa-bookmark-o'>bookmark-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-briefcase' ) ?> value='fa-briefcase'>briefcase</option>
									<option <?php selected( $item->VM_customIcon, 'fa-btc' ) ?> value='fa-btc'>btc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bug' ) ?> value='fa-bug'>bug</option>
									<option <?php selected( $item->VM_customIcon, 'fa-building' ) ?> value='fa-building'>building</option>
									<option <?php selected( $item->VM_customIcon, 'fa-building-o' ) ?> value='fa-building-o'>building-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bullhorn' ) ?> value='fa-bullhorn'>bullhorn</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bullseye' ) ?> value='fa-bullseye'>bullseye</option>
									<option <?php selected( $item->VM_customIcon, 'fa-bus' ) ?> value='fa-bus'>bus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-buysellads' ) ?> value='fa-buysellads'>buysellads</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cab' ) ?> value='fa-cab'>cab</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calculator' ) ?> value='fa-calculator'>calculator</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar' ) ?> value='fa-calendar'>calendar</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar-check-o' ) ?> value='fa-calendar-check-o'>calendar-check-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar-minus-o' ) ?> value='fa-calendar-minus-o'>calendar-minus-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar-o' ) ?> value='fa-calendar-o'>calendar-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar-plus-o' ) ?> value='fa-calendar-plus-o'>calendar-plus-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-calendar-times-o' ) ?> value='fa-calendar-times-o'>calendar-times-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-camera' ) ?> value='fa-camera'>camera</option>
									<option <?php selected( $item->VM_customIcon, 'fa-camera-retro' ) ?> value='fa-camera-retro'>camera-retro</option>
									<option <?php selected( $item->VM_customIcon, 'fa-car' ) ?> value='fa-car'>car</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-down' ) ?> value='fa-caret-down'>caret-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-left' ) ?> value='fa-caret-left'>caret-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-right' ) ?> value='fa-caret-right'>caret-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-square-o-down' ) ?> value='fa-caret-square-o-down'>caret-square-o-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-square-o-left' ) ?> value='fa-caret-square-o-left'>caret-square-o-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-square-o-right' ) ?> value='fa-caret-square-o-right'>caret-square-o-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-square-o-up' ) ?> value='fa-caret-square-o-up'>caret-square-o-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-caret-up' ) ?> value='fa-caret-up'>caret-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cart-arrow-down' ) ?> value='fa-cart-arrow-down'>cart-arrow-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cart-plus' ) ?> value='fa-cart-plus'>cart-plus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc' ) ?> value='fa-cc'>cc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-amex' ) ?> value='fa-cc-amex'>cc-amex</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-diners-club' ) ?> value='fa-cc-diners-club'>cc-diners-club</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-discover' ) ?> value='fa-cc-discover'>cc-discover</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-jcb' ) ?> value='fa-cc-jcb'>cc-jcb</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-mastercard' ) ?> value='fa-cc-mastercard'>cc-mastercard</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-paypal' ) ?> value='fa-cc-paypal'>cc-paypal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-stripe' ) ?> value='fa-cc-stripe'>cc-stripe</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cc-visa' ) ?> value='fa-cc-visa'>cc-visa</option>
									<option <?php selected( $item->VM_customIcon, 'fa-certificate' ) ?> value='fa-certificate'>certificate</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chain' ) ?> value='fa-chain'>chain</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chain-broken' ) ?> value='fa-chain-broken'>chain-broken</option>
									<option <?php selected( $item->VM_customIcon, 'fa-check' ) ?> value='fa-check'>check</option>
									<option <?php selected( $item->VM_customIcon, 'fa-check-circle' ) ?> value='fa-check-circle'>check-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-check-circle-o' ) ?> value='fa-check-circle-o'>check-circle-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-check-square' ) ?> value='fa-check-square'>check-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-check-square-o' ) ?> value='fa-check-square-o'>check-square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-circle-down' ) ?> value='fa-chevron-circle-down'>chevron-circle-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-circle-left' ) ?> value='fa-chevron-circle-left'>chevron-circle-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-circle-right' ) ?> value='fa-chevron-circle-right'>chevron-circle-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-circle-up' ) ?> value='fa-chevron-circle-up'>chevron-circle-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-down' ) ?> value='fa-chevron-down'>chevron-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-left' ) ?> value='fa-chevron-left'>chevron-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-right' ) ?> value='fa-chevron-right'>chevron-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chevron-up' ) ?> value='fa-chevron-up'>chevron-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-child' ) ?> value='fa-child'>child</option>
									<option <?php selected( $item->VM_customIcon, 'fa-chrome' ) ?> value='fa-chrome'>chrome</option>
									<option <?php selected( $item->VM_customIcon, 'fa-circle' ) ?> value='fa-circle'>circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-circle-o' ) ?> value='fa-circle-o'>circle-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-circle-o-notch' ) ?> value='fa-circle-o-notch'>circle-o-notch</option>
									<option <?php selected( $item->VM_customIcon, 'fa-circle-thin' ) ?> value='fa-circle-thin'>circle-thin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-clipboard' ) ?> value='fa-clipboard'>clipboard</option>
									<option <?php selected( $item->VM_customIcon, 'fa-clock-o' ) ?> value='fa-clock-o'>clock-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-clone' ) ?> value='fa-clone'>clone</option>
									<option <?php selected( $item->VM_customIcon, 'fa-close' ) ?> value='fa-close'>close</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cloud' ) ?> value='fa-cloud'>cloud</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cloud-download' ) ?> value='fa-cloud-download'>cloud-download</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cloud-upload' ) ?> value='fa-cloud-upload'>cloud-upload</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cny' ) ?> value='fa-cny'>cny</option>
									<option <?php selected( $item->VM_customIcon, 'fa-code' ) ?> value='fa-code'>code</option>
									<option <?php selected( $item->VM_customIcon, 'fa-code-fork' ) ?> value='fa-code-fork'>code-fork</option>
									<option <?php selected( $item->VM_customIcon, 'fa-codepen' ) ?> value='fa-codepen'>codepen</option>
									<option <?php selected( $item->VM_customIcon, 'fa-coffee' ) ?> value='fa-coffee'>coffee</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cog' ) ?> value='fa-cog'>cog</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cogs' ) ?> value='fa-cogs'>cogs</option>
									<option <?php selected( $item->VM_customIcon, 'fa-columns' ) ?> value='fa-columns'>columns</option>
									<option <?php selected( $item->VM_customIcon, 'fa-comment' ) ?> value='fa-comment'>comment</option>
									<option <?php selected( $item->VM_customIcon, 'fa-comment-o' ) ?> value='fa-comment-o'>comment-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-commenting' ) ?> value='fa-commenting'>commenting</option>
									<option <?php selected( $item->VM_customIcon, 'fa-commenting-o' ) ?> value='fa-commenting-o'>commenting-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-comments' ) ?> value='fa-comments'>comments</option>
									<option <?php selected( $item->VM_customIcon, 'fa-comments-o' ) ?> value='fa-comments-o'>comments-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-compass' ) ?> value='fa-compass'>compass</option>
									<option <?php selected( $item->VM_customIcon, 'fa-compress' ) ?> value='fa-compress'>compress</option>
									<option <?php selected( $item->VM_customIcon, 'fa-connectdevelop' ) ?> value='fa-connectdevelop'>connectdevelop</option>
									<option <?php selected( $item->VM_customIcon, 'fa-contao' ) ?> value='fa-contao'>contao</option>
									<option <?php selected( $item->VM_customIcon, 'fa-copy' ) ?> value='fa-copy'>copy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-copyright' ) ?> value='fa-copyright'>copyright</option>
									<option <?php selected( $item->VM_customIcon, 'fa-creative-commons' ) ?> value='fa-creative-commons'>creative-commons</option>
									<option <?php selected( $item->VM_customIcon, 'fa-credit-card' ) ?> value='fa-credit-card'>credit-card</option>
									<option <?php selected( $item->VM_customIcon, 'fa-crop' ) ?> value='fa-crop'>crop</option>
									<option <?php selected( $item->VM_customIcon, 'fa-crosshairs' ) ?> value='fa-crosshairs'>crosshairs</option>
									<option <?php selected( $item->VM_customIcon, 'fa-css3' ) ?> value='fa-css3'>css3</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cube' ) ?> value='fa-cube'>cube</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cubes' ) ?> value='fa-cubes'>cubes</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cut' ) ?> value='fa-cut'>cut</option>
									<option <?php selected( $item->VM_customIcon, 'fa-cutlery' ) ?> value='fa-cutlery'>cutlery</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dashboard' ) ?> value='fa-dashboard'>dashboard</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dashcube' ) ?> value='fa-dashcube'>dashcube</option>
									<option <?php selected( $item->VM_customIcon, 'fa-database' ) ?> value='fa-database'>database</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dedent' ) ?> value='fa-dedent'>dedent</option>
									<option <?php selected( $item->VM_customIcon, 'fa-delicious' ) ?> value='fa-delicious'>delicious</option>
									<option <?php selected( $item->VM_customIcon, 'fa-desktop' ) ?> value='fa-desktop'>desktop</option>
									<option <?php selected( $item->VM_customIcon, 'fa-deviantart' ) ?> value='fa-deviantart'>deviantart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-diamond' ) ?> value='fa-diamond'>diamond</option>
									<option <?php selected( $item->VM_customIcon, 'fa-digg' ) ?> value='fa-digg'>digg</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dollar' ) ?> value='fa-dollar'>dollar</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dot-circle-o' ) ?> value='fa-dot-circle-o'>dot-circle-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-download' ) ?> value='fa-download'>download</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dribbble' ) ?> value='fa-dribbble'>dribbble</option>
									<option <?php selected( $item->VM_customIcon, 'fa-dropbox' ) ?> value='fa-dropbox'>dropbox</option>
									<option <?php selected( $item->VM_customIcon, 'fa-drupal' ) ?> value='fa-drupal'>drupal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-edit' ) ?> value='fa-edit'>edit</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eject' ) ?> value='fa-eject'>eject</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ellipsis-h' ) ?> value='fa-ellipsis-h'>ellipsis-h</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ellipsis-v' ) ?> value='fa-ellipsis-v'>ellipsis-v</option>
									<option <?php selected( $item->VM_customIcon, 'fa-empire' ) ?> value='fa-empire'>empire</option>
									<option <?php selected( $item->VM_customIcon, 'fa-envelope' ) ?> value='fa-envelope'>envelope</option>
									<option <?php selected( $item->VM_customIcon, 'fa-envelope-o' ) ?> value='fa-envelope-o'>envelope-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-envelope-square' ) ?> value='fa-envelope-square'>envelope-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eraser' ) ?> value='fa-eraser'>eraser</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eur' ) ?> value='fa-eur'>eur</option>
									<option <?php selected( $item->VM_customIcon, 'fa-euro' ) ?> value='fa-euro'>euro</option>
									<option <?php selected( $item->VM_customIcon, 'fa-exchange' ) ?> value='fa-exchange'>exchange</option>
									<option <?php selected( $item->VM_customIcon, 'fa-exclamation' ) ?> value='fa-exclamation'>exclamation</option>
									<option <?php selected( $item->VM_customIcon, 'fa-exclamation-circle' ) ?> value='fa-exclamation-circle'>exclamation-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-exclamation-triangle' ) ?> value='fa-exclamation-triangle'>exclamation-triangle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-expand' ) ?> value='fa-expand'>expand</option>
									<option <?php selected( $item->VM_customIcon, 'fa-expeditedssl' ) ?> value='fa-expeditedssl'>expeditedssl</option>
									<option <?php selected( $item->VM_customIcon, 'fa-external-link' ) ?> value='fa-external-link'>external-link</option>
									<option <?php selected( $item->VM_customIcon, 'fa-external-link-square' ) ?> value='fa-external-link-square'>external-link-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eye' ) ?> value='fa-eye'>eye</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eye-slash' ) ?> value='fa-eye-slash'>eye-slash</option>
									<option <?php selected( $item->VM_customIcon, 'fa-eyedropper' ) ?> value='fa-eyedropper'>eyedropper</option>
									<option <?php selected( $item->VM_customIcon, 'fa-facebook' ) ?> value='fa-facebook'>facebook</option>
									<option <?php selected( $item->VM_customIcon, 'fa-facebook-f' ) ?> value='fa-facebook-f'>facebook-f</option>
									<option <?php selected( $item->VM_customIcon, 'fa-facebook-official' ) ?> value='fa-facebook-official'>facebook-official</option>
									<option <?php selected( $item->VM_customIcon, 'fa-facebook-square' ) ?> value='fa-facebook-square'>facebook-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fast-backward' ) ?> value='fa-fast-backward'>fast-backward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fast-forward' ) ?> value='fa-fast-forward'>fast-forward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fax' ) ?> value='fa-fax'>fax</option>
									<option <?php selected( $item->VM_customIcon, 'fa-feed' ) ?> value='fa-feed'>feed</option>
									<option <?php selected( $item->VM_customIcon, 'fa-female' ) ?> value='fa-female'>female</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fighter-jet' ) ?> value='fa-fighter-jet'>fighter-jet</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file' ) ?> value='fa-file'>file</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-archive-o' ) ?> value='fa-file-archive-o'>file-archive-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-audio-o' ) ?> value='fa-file-audio-o'>file-audio-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-code-o' ) ?> value='fa-file-code-o'>file-code-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-excel-o' ) ?> value='fa-file-excel-o'>file-excel-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-image-o' ) ?> value='fa-file-image-o'>file-image-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-movie-o' ) ?> value='fa-file-movie-o'>file-movie-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-o' ) ?> value='fa-file-o'>file-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-pdf-o' ) ?> value='fa-file-pdf-o'>file-pdf-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-photo-o' ) ?> value='fa-file-photo-o'>file-photo-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-picture-o' ) ?> value='fa-file-picture-o'>file-picture-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-powerpoint-o' ) ?> value='fa-file-powerpoint-o'>file-powerpoint-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-sound-o' ) ?> value='fa-file-sound-o'>file-sound-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-text' ) ?> value='fa-file-text'>file-text</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-text-o' ) ?> value='fa-file-text-o'>file-text-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-video-o' ) ?> value='fa-file-video-o'>file-video-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-word-o' ) ?> value='fa-file-word-o'>file-word-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-file-zip-o' ) ?> value='fa-file-zip-o'>file-zip-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-files-o' ) ?> value='fa-files-o'>files-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-film' ) ?> value='fa-film'>film</option>
									<option <?php selected( $item->VM_customIcon, 'fa-filter' ) ?> value='fa-filter'>filter</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fire' ) ?> value='fa-fire'>fire</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fire-extinguisher' ) ?> value='fa-fire-extinguisher'>fire-extinguisher</option>
									<option <?php selected( $item->VM_customIcon, 'fa-firefox' ) ?> value='fa-firefox'>firefox</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flag' ) ?> value='fa-flag'>flag</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flag-checkered' ) ?> value='fa-flag-checkered'>flag-checkered</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flag-o' ) ?> value='fa-flag-o'>flag-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flash' ) ?> value='fa-flash'>flash</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flask' ) ?> value='fa-flask'>flask</option>
									<option <?php selected( $item->VM_customIcon, 'fa-flickr' ) ?> value='fa-flickr'>flickr</option>
									<option <?php selected( $item->VM_customIcon, 'fa-floppy-o' ) ?> value='fa-floppy-o'>floppy-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-folder' ) ?> value='fa-folder'>folder</option>
									<option <?php selected( $item->VM_customIcon, 'fa-folder-o' ) ?> value='fa-folder-o'>folder-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-folder-open' ) ?> value='fa-folder-open'>folder-open</option>
									<option <?php selected( $item->VM_customIcon, 'fa-folder-open-o' ) ?> value='fa-folder-open-o'>folder-open-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-font' ) ?> value='fa-font'>font</option>
									<option <?php selected( $item->VM_customIcon, 'fa-fonticons' ) ?> value='fa-fonticons'>fonticons</option>
									<option <?php selected( $item->VM_customIcon, 'fa-forumbee' ) ?> value='fa-forumbee'>forumbee</option>
									<option <?php selected( $item->VM_customIcon, 'fa-forward' ) ?> value='fa-forward'>forward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-foursquare' ) ?> value='fa-foursquare'>foursquare</option>
									<option <?php selected( $item->VM_customIcon, 'fa-frown-o' ) ?> value='fa-frown-o'>frown-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-futbol-o' ) ?> value='fa-futbol-o'>futbol-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gamepad' ) ?> value='fa-gamepad'>gamepad</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gavel' ) ?> value='fa-gavel'>gavel</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gbp' ) ?> value='fa-gbp'>gbp</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ge' ) ?> value='fa-ge'>ge</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gear' ) ?> value='fa-gear'>gear</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gears' ) ?> value='fa-gears'>gears</option>
									<option <?php selected( $item->VM_customIcon, 'fa-genderless' ) ?> value='fa-genderless'>genderless</option>
									<option <?php selected( $item->VM_customIcon, 'fa-get-pocket' ) ?> value='fa-get-pocket'>get-pocket</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gg' ) ?> value='fa-gg'>gg</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gg-circle' ) ?> value='fa-gg-circle'>gg-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gift' ) ?> value='fa-gift'>gift</option>
									<option <?php selected( $item->VM_customIcon, 'fa-git' ) ?> value='fa-git'>git</option>
									<option <?php selected( $item->VM_customIcon, 'fa-git-square' ) ?> value='fa-git-square'>git-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-github' ) ?> value='fa-github'>github</option>
									<option <?php selected( $item->VM_customIcon, 'fa-github-alt' ) ?> value='fa-github-alt'>github-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-github-square' ) ?> value='fa-github-square'>github-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gittip' ) ?> value='fa-gittip'>gittip</option>
									<option <?php selected( $item->VM_customIcon, 'fa-glass' ) ?> value='fa-glass'>glass</option>
									<option <?php selected( $item->VM_customIcon, 'fa-globe' ) ?> value='fa-globe'>globe</option>
									<option <?php selected( $item->VM_customIcon, 'fa-google' ) ?> value='fa-google'>google</option>
									<option <?php selected( $item->VM_customIcon, 'fa-google-plus' ) ?> value='fa-google-plus'>google-plus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-google-plus-square' ) ?> value='fa-google-plus-square'>google-plus-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-google-wallet' ) ?> value='fa-google-wallet'>google-wallet</option>
									<option <?php selected( $item->VM_customIcon, 'fa-graduation-cap' ) ?> value='fa-graduation-cap'>graduation-cap</option>
									<option <?php selected( $item->VM_customIcon, 'fa-gratipay' ) ?> value='fa-gratipay'>gratipay</option>
									<option <?php selected( $item->VM_customIcon, 'fa-group' ) ?> value='fa-group'>group</option>
									<option <?php selected( $item->VM_customIcon, 'fa-h-square' ) ?> value='fa-h-square'>h-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hacker-news' ) ?> value='fa-hacker-news'>hacker-news</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-grab-o' ) ?> value='fa-hand-grab-o'>hand-grab-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-lizard-o' ) ?> value='fa-hand-lizard-o'>hand-lizard-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-o-down' ) ?> value='fa-hand-o-down'>hand-o-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-o-left' ) ?> value='fa-hand-o-left'>hand-o-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-o-right' ) ?> value='fa-hand-o-right'>hand-o-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-o-up' ) ?> value='fa-hand-o-up'>hand-o-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-paper-o' ) ?> value='fa-hand-paper-o'>hand-paper-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-peace-o' ) ?> value='fa-hand-peace-o'>hand-peace-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-pointer-o' ) ?> value='fa-hand-pointer-o'>hand-pointer-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-rock-o' ) ?> value='fa-hand-rock-o'>hand-rock-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-scissors-o' ) ?> value='fa-hand-scissors-o'>hand-scissors-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-spock-o' ) ?> value='fa-hand-spock-o'>hand-spock-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hand-stop-o' ) ?> value='fa-hand-stop-o'>hand-stop-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hdd-o' ) ?> value='fa-hdd-o'>hdd-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-header' ) ?> value='fa-header'>header</option>
									<option <?php selected( $item->VM_customIcon, 'fa-headphones' ) ?> value='fa-headphones'>headphones</option>
									<option <?php selected( $item->VM_customIcon, 'fa-heart' ) ?> value='fa-heart'>heart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-heart-o' ) ?> value='fa-heart-o'>heart-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-heartbeat' ) ?> value='fa-heartbeat'>heartbeat</option>
									<option <?php selected( $item->VM_customIcon, 'fa-history' ) ?> value='fa-history'>history</option>
									<option <?php selected( $item->VM_customIcon, 'fa-home' ) ?> value='fa-home'>home</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hospital-o' ) ?> value='fa-hospital-o'>hospital-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hotel' ) ?> value='fa-hotel'>hotel</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass' ) ?> value='fa-hourglass'>hourglass</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-1' ) ?> value='fa-hourglass-1'>hourglass-1</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-2' ) ?> value='fa-hourglass-2'>hourglass-2</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-3' ) ?> value='fa-hourglass-3'>hourglass-3</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-end' ) ?> value='fa-hourglass-end'>hourglass-end</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-half' ) ?> value='fa-hourglass-half'>hourglass-half</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-o' ) ?> value='fa-hourglass-o'>hourglass-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-hourglass-start' ) ?> value='fa-hourglass-start'>hourglass-start</option>
									<option <?php selected( $item->VM_customIcon, 'fa-houzz' ) ?> value='fa-houzz'>houzz</option>
									<option <?php selected( $item->VM_customIcon, 'fa-html5' ) ?> value='fa-html5'>html5</option>
									<option <?php selected( $item->VM_customIcon, 'fa-i-cursor' ) ?> value='fa-i-cursor'>i-cursor</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ils' ) ?> value='fa-ils'>ils</option>
									<option <?php selected( $item->VM_customIcon, 'fa-image' ) ?> value='fa-image'>image</option>
									<option <?php selected( $item->VM_customIcon, 'fa-inbox' ) ?> value='fa-inbox'>inbox</option>
									<option <?php selected( $item->VM_customIcon, 'fa-indent' ) ?> value='fa-indent'>indent</option>
									<option <?php selected( $item->VM_customIcon, 'fa-industry' ) ?> value='fa-industry'>industry</option>
									<option <?php selected( $item->VM_customIcon, 'fa-info' ) ?> value='fa-info'>info</option>
									<option <?php selected( $item->VM_customIcon, 'fa-info-circle' ) ?> value='fa-info-circle'>info-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-inr' ) ?> value='fa-inr'>inr</option>
									<option <?php selected( $item->VM_customIcon, 'fa-instagram' ) ?> value='fa-instagram'>instagram</option>
									<option <?php selected( $item->VM_customIcon, 'fa-institution' ) ?> value='fa-institution'>institution</option>
									<option <?php selected( $item->VM_customIcon, 'fa-internet-explorer' ) ?> value='fa-internet-explorer'>internet-explorer</option>
									<option <?php selected( $item->VM_customIcon, 'fa-intersex' ) ?> value='fa-intersex'>intersex</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ioxhost' ) ?> value='fa-ioxhost'>ioxhost</option>
									<option <?php selected( $item->VM_customIcon, 'fa-italic' ) ?> value='fa-italic'>italic</option>
									<option <?php selected( $item->VM_customIcon, 'fa-joomla' ) ?> value='fa-joomla'>joomla</option>
									<option <?php selected( $item->VM_customIcon, 'fa-jpy' ) ?> value='fa-jpy'>jpy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-jsfiddle' ) ?> value='fa-jsfiddle'>jsfiddle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-key' ) ?> value='fa-key'>key</option>
									<option <?php selected( $item->VM_customIcon, 'fa-keyboard-o' ) ?> value='fa-keyboard-o'>keyboard-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-krw' ) ?> value='fa-krw'>krw</option>
									<option <?php selected( $item->VM_customIcon, 'fa-language' ) ?> value='fa-language'>language</option>
									<option <?php selected( $item->VM_customIcon, 'fa-laptop' ) ?> value='fa-laptop'>laptop</option>
									<option <?php selected( $item->VM_customIcon, 'fa-lastfm' ) ?> value='fa-lastfm'>lastfm</option>
									<option <?php selected( $item->VM_customIcon, 'fa-lastfm-square' ) ?> value='fa-lastfm-square'>lastfm-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-leaf' ) ?> value='fa-leaf'>leaf</option>
									<option <?php selected( $item->VM_customIcon, 'fa-leanpub' ) ?> value='fa-leanpub'>leanpub</option>
									<option <?php selected( $item->VM_customIcon, 'fa-legal' ) ?> value='fa-legal'>legal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-lemon-o' ) ?> value='fa-lemon-o'>lemon-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-level-down' ) ?> value='fa-level-down'>level-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-level-up' ) ?> value='fa-level-up'>level-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-life-bouy' ) ?> value='fa-life-bouy'>life-bouy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-life-buoy' ) ?> value='fa-life-buoy'>life-buoy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-life-ring' ) ?> value='fa-life-ring'>life-ring</option>
									<option <?php selected( $item->VM_customIcon, 'fa-life-saver' ) ?> value='fa-life-saver'>life-saver</option>
									<option <?php selected( $item->VM_customIcon, 'fa-lightbulb-o' ) ?> value='fa-lightbulb-o'>lightbulb-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-line-chart' ) ?> value='fa-line-chart'>line-chart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-link' ) ?> value='fa-link'>link</option>
									<option <?php selected( $item->VM_customIcon, 'fa-linkedin' ) ?> value='fa-linkedin'>linkedin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-linkedin-square' ) ?> value='fa-linkedin-square'>linkedin-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-linux' ) ?> value='fa-linux'>linux</option>
									<option <?php selected( $item->VM_customIcon, 'fa-list' ) ?> value='fa-list'>list</option>
									<option <?php selected( $item->VM_customIcon, 'fa-list-alt' ) ?> value='fa-list-alt'>list-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-list-ol' ) ?> value='fa-list-ol'>list-ol</option>
									<option <?php selected( $item->VM_customIcon, 'fa-list-ul' ) ?> value='fa-list-ul'>list-ul</option>
									<option <?php selected( $item->VM_customIcon, 'fa-location-arrow' ) ?> value='fa-location-arrow'>location-arrow</option>
									<option <?php selected( $item->VM_customIcon, 'fa-lock' ) ?> value='fa-lock'>lock</option>
									<option <?php selected( $item->VM_customIcon, 'fa-long-arrow-down' ) ?> value='fa-long-arrow-down'>long-arrow-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-long-arrow-left' ) ?> value='fa-long-arrow-left'>long-arrow-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-long-arrow-right' ) ?> value='fa-long-arrow-right'>long-arrow-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-long-arrow-up' ) ?> value='fa-long-arrow-up'>long-arrow-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-magic' ) ?> value='fa-magic'>magic</option>
									<option <?php selected( $item->VM_customIcon, 'fa-magnet' ) ?> value='fa-magnet'>magnet</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mail-forward' ) ?> value='fa-mail-forward'>mail-forward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mail-reply' ) ?> value='fa-mail-reply'>mail-reply</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mail-reply-all' ) ?> value='fa-mail-reply-all'>mail-reply-all</option>
									<option <?php selected( $item->VM_customIcon, 'fa-male' ) ?> value='fa-male'>male</option>
									<option <?php selected( $item->VM_customIcon, 'fa-map' ) ?> value='fa-map'>map</option>
									<option <?php selected( $item->VM_customIcon, 'fa-map-marker' ) ?> value='fa-map-marker'>map-marker</option>
									<option <?php selected( $item->VM_customIcon, 'fa-map-o' ) ?> value='fa-map-o'>map-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-map-pin' ) ?> value='fa-map-pin'>map-pin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-map-signs' ) ?> value='fa-map-signs'>map-signs</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mars' ) ?> value='fa-mars'>mars</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mars-double' ) ?> value='fa-mars-double'>mars-double</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mars-stroke' ) ?> value='fa-mars-stroke'>mars-stroke</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mars-stroke-h' ) ?> value='fa-mars-stroke-h'>mars-stroke-h</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mars-stroke-v' ) ?> value='fa-mars-stroke-v'>mars-stroke-v</option>
									<option <?php selected( $item->VM_customIcon, 'fa-maxcdn' ) ?> value='fa-maxcdn'>maxcdn</option>
									<option <?php selected( $item->VM_customIcon, 'fa-meanpath' ) ?> value='fa-meanpath'>meanpath</option>
									<option <?php selected( $item->VM_customIcon, 'fa-medium' ) ?> value='fa-medium'>medium</option>
									<option <?php selected( $item->VM_customIcon, 'fa-medkit' ) ?> value='fa-medkit'>medkit</option>
									<option <?php selected( $item->VM_customIcon, 'fa-meh-o' ) ?> value='fa-meh-o'>meh-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mercury' ) ?> value='fa-mercury'>mercury</option>
									<option <?php selected( $item->VM_customIcon, 'fa-microphone' ) ?> value='fa-microphone'>microphone</option>
									<option <?php selected( $item->VM_customIcon, 'fa-microphone-slash' ) ?> value='fa-microphone-slash'>microphone-slash</option>
									<option <?php selected( $item->VM_customIcon, 'fa-minus' ) ?> value='fa-minus'>minus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-minus-circle' ) ?> value='fa-minus-circle'>minus-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-minus-square' ) ?> value='fa-minus-square'>minus-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-minus-square-o' ) ?> value='fa-minus-square-o'>minus-square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mobile' ) ?> value='fa-mobile'>mobile</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mobile-phone' ) ?> value='fa-mobile-phone'>mobile-phone</option>
									<option <?php selected( $item->VM_customIcon, 'fa-money' ) ?> value='fa-money'>money</option>
									<option <?php selected( $item->VM_customIcon, 'fa-moon-o' ) ?> value='fa-moon-o'>moon-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mortar-board' ) ?> value='fa-mortar-board'>mortar-board</option>
									<option <?php selected( $item->VM_customIcon, 'fa-motorcycle' ) ?> value='fa-motorcycle'>motorcycle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-mouse-pointer' ) ?> value='fa-mouse-pointer'>mouse-pointer</option>
									<option <?php selected( $item->VM_customIcon, 'fa-music' ) ?> value='fa-music'>music</option>
									<option <?php selected( $item->VM_customIcon, 'fa-navicon' ) ?> value='fa-navicon'>navicon</option>
									<option <?php selected( $item->VM_customIcon, 'fa-neuter' ) ?> value='fa-neuter'>neuter</option>
									<option <?php selected( $item->VM_customIcon, 'fa-newspaper-o' ) ?> value='fa-newspaper-o'>newspaper-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-object-group' ) ?> value='fa-object-group'>object-group</option>
									<option <?php selected( $item->VM_customIcon, 'fa-object-ungroup' ) ?> value='fa-object-ungroup'>object-ungroup</option>
									<option <?php selected( $item->VM_customIcon, 'fa-odnoklassniki' ) ?> value='fa-odnoklassniki'>odnoklassniki</option>
									<option <?php selected( $item->VM_customIcon, 'fa-odnoklassniki-square' ) ?> value='fa-odnoklassniki-square'>odnoklassniki-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-opencart' ) ?> value='fa-opencart'>opencart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-openid' ) ?> value='fa-openid'>openid</option>
									<option <?php selected( $item->VM_customIcon, 'fa-opera' ) ?> value='fa-opera'>opera</option>
									<option <?php selected( $item->VM_customIcon, 'fa-optin-monster' ) ?> value='fa-optin-monster'>optin-monster</option>
									<option <?php selected( $item->VM_customIcon, 'fa-outdent' ) ?> value='fa-outdent'>outdent</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pagelines' ) ?> value='fa-pagelines'>pagelines</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paint-brush' ) ?> value='fa-paint-brush'>paint-brush</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paper-plane' ) ?> value='fa-paper-plane'>paper-plane</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paper-plane-o' ) ?> value='fa-paper-plane-o'>paper-plane-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paperclip' ) ?> value='fa-paperclip'>paperclip</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paragraph' ) ?> value='fa-paragraph'>paragraph</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paste' ) ?> value='fa-paste'>paste</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pause' ) ?> value='fa-pause'>pause</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paw' ) ?> value='fa-paw'>paw</option>
									<option <?php selected( $item->VM_customIcon, 'fa-paypal' ) ?> value='fa-paypal'>paypal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pencil' ) ?> value='fa-pencil'>pencil</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pencil-square' ) ?> value='fa-pencil-square'>pencil-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pencil-square-o' ) ?> value='fa-pencil-square-o'>pencil-square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-phone' ) ?> value='fa-phone'>phone</option>
									<option <?php selected( $item->VM_customIcon, 'fa-phone-square' ) ?> value='fa-phone-square'>phone-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-photo' ) ?> value='fa-photo'>photo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-picture-o' ) ?> value='fa-picture-o'>picture-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pie-chart' ) ?> value='fa-pie-chart'>pie-chart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pied-piper' ) ?> value='fa-pied-piper'>pied-piper</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pied-piper-alt' ) ?> value='fa-pied-piper-alt'>pied-piper-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pinterest' ) ?> value='fa-pinterest'>pinterest</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pinterest-p' ) ?> value='fa-pinterest-p'>pinterest-p</option>
									<option <?php selected( $item->VM_customIcon, 'fa-pinterest-square' ) ?> value='fa-pinterest-square'>pinterest-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plane' ) ?> value='fa-plane'>plane</option>
									<option <?php selected( $item->VM_customIcon, 'fa-play' ) ?> value='fa-play'>play</option>
									<option <?php selected( $item->VM_customIcon, 'fa-play-circle' ) ?> value='fa-play-circle'>play-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-play-circle-o' ) ?> value='fa-play-circle-o'>play-circle-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plug' ) ?> value='fa-plug'>plug</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plus' ) ?> value='fa-plus'>plus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plus-circle' ) ?> value='fa-plus-circle'>plus-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plus-square' ) ?> value='fa-plus-square'>plus-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-plus-square-o' ) ?> value='fa-plus-square-o'>plus-square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-power-off' ) ?> value='fa-power-off'>power-off</option>
									<option <?php selected( $item->VM_customIcon, 'fa-print' ) ?> value='fa-print'>print</option>
									<option <?php selected( $item->VM_customIcon, 'fa-puzzle-piece' ) ?> value='fa-puzzle-piece'>puzzle-piece</option>
									<option <?php selected( $item->VM_customIcon, 'fa-qq' ) ?> value='fa-qq'>qq</option>
									<option <?php selected( $item->VM_customIcon, 'fa-qrcode' ) ?> value='fa-qrcode'>qrcode</option>
									<option <?php selected( $item->VM_customIcon, 'fa-question' ) ?> value='fa-question'>question</option>
									<option <?php selected( $item->VM_customIcon, 'fa-question-circle' ) ?> value='fa-question-circle'>question-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-quote-left' ) ?> value='fa-quote-left'>quote-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-quote-right' ) ?> value='fa-quote-right'>quote-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ra' ) ?> value='fa-ra'>ra</option>
									<option <?php selected( $item->VM_customIcon, 'fa-random' ) ?> value='fa-random'>random</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rebel' ) ?> value='fa-rebel'>rebel</option>
									<option <?php selected( $item->VM_customIcon, 'fa-recycle' ) ?> value='fa-recycle'>recycle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-reddit' ) ?> value='fa-reddit'>reddit</option>
									<option <?php selected( $item->VM_customIcon, 'fa-reddit-square' ) ?> value='fa-reddit-square'>reddit-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-refresh' ) ?> value='fa-refresh'>refresh</option>
									<option <?php selected( $item->VM_customIcon, 'fa-registered' ) ?> value='fa-registered'>registered</option>
									<option <?php selected( $item->VM_customIcon, 'fa-remove' ) ?> value='fa-remove'>remove</option>
									<option <?php selected( $item->VM_customIcon, 'fa-renren' ) ?> value='fa-renren'>renren</option>
									<option <?php selected( $item->VM_customIcon, 'fa-reorder' ) ?> value='fa-reorder'>reorder</option>
									<option <?php selected( $item->VM_customIcon, 'fa-repeat' ) ?> value='fa-repeat'>repeat</option>
									<option <?php selected( $item->VM_customIcon, 'fa-reply' ) ?> value='fa-reply'>reply</option>
									<option <?php selected( $item->VM_customIcon, 'fa-reply-all' ) ?> value='fa-reply-all'>reply-all</option>
									<option <?php selected( $item->VM_customIcon, 'fa-retweet' ) ?> value='fa-retweet'>retweet</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rmb' ) ?> value='fa-rmb'>rmb</option>
									<option <?php selected( $item->VM_customIcon, 'fa-road' ) ?> value='fa-road'>road</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rocket' ) ?> value='fa-rocket'>rocket</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rotate-left' ) ?> value='fa-rotate-left'>rotate-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rotate-right' ) ?> value='fa-rotate-right'>rotate-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rouble' ) ?> value='fa-rouble'>rouble</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rss' ) ?> value='fa-rss'>rss</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rss-square' ) ?> value='fa-rss-square'>rss-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rub' ) ?> value='fa-rub'>rub</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ruble' ) ?> value='fa-ruble'>ruble</option>
									<option <?php selected( $item->VM_customIcon, 'fa-rupee' ) ?> value='fa-rupee'>rupee</option>
									<option <?php selected( $item->VM_customIcon, 'fa-safari' ) ?> value='fa-safari'>safari</option>
									<option <?php selected( $item->VM_customIcon, 'fa-save' ) ?> value='fa-save'>save</option>
									<option <?php selected( $item->VM_customIcon, 'fa-scissors' ) ?> value='fa-scissors'>scissors</option>
									<option <?php selected( $item->VM_customIcon, 'fa-search' ) ?> value='fa-search'>search</option>
									<option <?php selected( $item->VM_customIcon, 'fa-search-minus' ) ?> value='fa-search-minus'>search-minus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-search-plus' ) ?> value='fa-search-plus'>search-plus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sellsy' ) ?> value='fa-sellsy'>sellsy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-send' ) ?> value='fa-send'>send</option>
									<option <?php selected( $item->VM_customIcon, 'fa-send-o' ) ?> value='fa-send-o'>send-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-server' ) ?> value='fa-server'>server</option>
									<option <?php selected( $item->VM_customIcon, 'fa-share' ) ?> value='fa-share'>share</option>
									<option <?php selected( $item->VM_customIcon, 'fa-share-alt' ) ?> value='fa-share-alt'>share-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-share-alt-square' ) ?> value='fa-share-alt-square'>share-alt-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-share-square' ) ?> value='fa-share-square'>share-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-share-square-o' ) ?> value='fa-share-square-o'>share-square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-shekel' ) ?> value='fa-shekel'>shekel</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sheqel' ) ?> value='fa-sheqel'>sheqel</option>
									<option <?php selected( $item->VM_customIcon, 'fa-shield' ) ?> value='fa-shield'>shield</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ship' ) ?> value='fa-ship'>ship</option>
									<option <?php selected( $item->VM_customIcon, 'fa-shirtsinbulk' ) ?> value='fa-shirtsinbulk'>shirtsinbulk</option>
									<option <?php selected( $item->VM_customIcon, 'fa-shopping-cart' ) ?> value='fa-shopping-cart'>shopping-cart</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sign-in' ) ?> value='fa-sign-in'>sign-in</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sign-out' ) ?> value='fa-sign-out'>sign-out</option>
									<option <?php selected( $item->VM_customIcon, 'fa-signal' ) ?> value='fa-signal'>signal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-simplybuilt' ) ?> value='fa-simplybuilt'>simplybuilt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sitemap' ) ?> value='fa-sitemap'>sitemap</option>
									<option <?php selected( $item->VM_customIcon, 'fa-skyatlas' ) ?> value='fa-skyatlas'>skyatlas</option>
									<option <?php selected( $item->VM_customIcon, 'fa-skype' ) ?> value='fa-skype'>skype</option>
									<option <?php selected( $item->VM_customIcon, 'fa-slack' ) ?> value='fa-slack'>slack</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sliders' ) ?> value='fa-sliders'>sliders</option>
									<option <?php selected( $item->VM_customIcon, 'fa-slideshare' ) ?> value='fa-slideshare'>slideshare</option>
									<option <?php selected( $item->VM_customIcon, 'fa-smile-o' ) ?> value='fa-smile-o'>smile-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-soccer-ball-o' ) ?> value='fa-soccer-ball-o'>soccer-ball-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort' ) ?> value='fa-sort'>sort</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-alpha-asc' ) ?> value='fa-sort-alpha-asc'>sort-alpha-asc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-alpha-desc' ) ?> value='fa-sort-alpha-desc'>sort-alpha-desc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-amount-asc' ) ?> value='fa-sort-amount-asc'>sort-amount-asc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-amount-desc' ) ?> value='fa-sort-amount-desc'>sort-amount-desc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-asc' ) ?> value='fa-sort-asc'>sort-asc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-desc' ) ?> value='fa-sort-desc'>sort-desc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-down' ) ?> value='fa-sort-down'>sort-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-numeric-asc' ) ?> value='fa-sort-numeric-asc'>sort-numeric-asc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-numeric-desc' ) ?> value='fa-sort-numeric-desc'>sort-numeric-desc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sort-up' ) ?> value='fa-sort-up'>sort-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-soundcloud' ) ?> value='fa-soundcloud'>soundcloud</option>
									<option <?php selected( $item->VM_customIcon, 'fa-space-shuttle' ) ?> value='fa-space-shuttle'>space-shuttle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-spinner' ) ?> value='fa-spinner'>spinner</option>
									<option <?php selected( $item->VM_customIcon, 'fa-spoon' ) ?> value='fa-spoon'>spoon</option>
									<option <?php selected( $item->VM_customIcon, 'fa-spotify' ) ?> value='fa-spotify'>spotify</option>
									<option <?php selected( $item->VM_customIcon, 'fa-square' ) ?> value='fa-square'>square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-square-o' ) ?> value='fa-square-o'>square-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stack-exchange' ) ?> value='fa-stack-exchange'>stack-exchange</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stack-overflow' ) ?> value='fa-stack-overflow'>stack-overflow</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star' ) ?> value='fa-star'>star</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star-half' ) ?> value='fa-star-half'>star-half</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star-half-empty' ) ?> value='fa-star-half-empty'>star-half-empty</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star-half-full' ) ?> value='fa-star-half-full'>star-half-full</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star-half-o' ) ?> value='fa-star-half-o'>star-half-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-star-o' ) ?> value='fa-star-o'>star-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-steam' ) ?> value='fa-steam'>steam</option>
									<option <?php selected( $item->VM_customIcon, 'fa-steam-square' ) ?> value='fa-steam-square'>steam-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-step-backward' ) ?> value='fa-step-backward'>step-backward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-step-forward' ) ?> value='fa-step-forward'>step-forward</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stethoscope' ) ?> value='fa-stethoscope'>stethoscope</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sticky-note' ) ?> value='fa-sticky-note'>sticky-note</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sticky-note-o' ) ?> value='fa-sticky-note-o'>sticky-note-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stop' ) ?> value='fa-stop'>stop</option>
									<option <?php selected( $item->VM_customIcon, 'fa-street-view' ) ?> value='fa-street-view'>street-view</option>
									<option <?php selected( $item->VM_customIcon, 'fa-strikethrough' ) ?> value='fa-strikethrough'>strikethrough</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stumbleupon' ) ?> value='fa-stumbleupon'>stumbleupon</option>
									<option <?php selected( $item->VM_customIcon, 'fa-stumbleupon-circle' ) ?> value='fa-stumbleupon-circle'>stumbleupon-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-subscript' ) ?> value='fa-subscript'>subscript</option>
									<option <?php selected( $item->VM_customIcon, 'fa-subway' ) ?> value='fa-subway'>subway</option>
									<option <?php selected( $item->VM_customIcon, 'fa-suitcase' ) ?> value='fa-suitcase'>suitcase</option>
									<option <?php selected( $item->VM_customIcon, 'fa-sun-o' ) ?> value='fa-sun-o'>sun-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-superscript' ) ?> value='fa-superscript'>superscript</option>
									<option <?php selected( $item->VM_customIcon, 'fa-support' ) ?> value='fa-support'>support</option>
									<option <?php selected( $item->VM_customIcon, 'fa-table' ) ?> value='fa-table'>table</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tablet' ) ?> value='fa-tablet'>tablet</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tachometer' ) ?> value='fa-tachometer'>tachometer</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tag' ) ?> value='fa-tag'>tag</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tags' ) ?> value='fa-tags'>tags</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tasks' ) ?> value='fa-tasks'>tasks</option>
									<option <?php selected( $item->VM_customIcon, 'fa-taxi' ) ?> value='fa-taxi'>taxi</option>
									<option <?php selected( $item->VM_customIcon, 'fa-television' ) ?> value='fa-television'>television</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tencent-weibo' ) ?> value='fa-tencent-weibo'>tencent-weibo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-terminal' ) ?> value='fa-terminal'>terminal</option>
									<option <?php selected( $item->VM_customIcon, 'fa-text-height' ) ?> value='fa-text-height'>text-height</option>
									<option <?php selected( $item->VM_customIcon, 'fa-text-width' ) ?> value='fa-text-width'>text-width</option>
									<option <?php selected( $item->VM_customIcon, 'fa-th' ) ?> value='fa-th'>th</option>
									<option <?php selected( $item->VM_customIcon, 'fa-th-large' ) ?> value='fa-th-large'>th-large</option>
									<option <?php selected( $item->VM_customIcon, 'fa-th-list' ) ?> value='fa-th-list'>th-list</option>
									<option <?php selected( $item->VM_customIcon, 'fa-thumb-tack' ) ?> value='fa-thumb-tack'>thumb-tack</option>
									<option <?php selected( $item->VM_customIcon, 'fa-thumbs-down' ) ?> value='fa-thumbs-down'>thumbs-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-thumbs-o-down' ) ?> value='fa-thumbs-o-down'>thumbs-o-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-thumbs-o-up' ) ?> value='fa-thumbs-o-up'>thumbs-o-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-thumbs-up' ) ?> value='fa-thumbs-up'>thumbs-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-ticket' ) ?> value='fa-ticket'>ticket</option>
									<option <?php selected( $item->VM_customIcon, 'fa-times' ) ?> value='fa-times'>times</option>
									<option <?php selected( $item->VM_customIcon, 'fa-times-circle' ) ?> value='fa-times-circle'>times-circle</option>
									<option <?php selected( $item->VM_customIcon, 'fa-times-circle-o' ) ?> value='fa-times-circle-o'>times-circle-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tint' ) ?> value='fa-tint'>tint</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-down' ) ?> value='fa-toggle-down'>toggle-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-left' ) ?> value='fa-toggle-left'>toggle-left</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-off' ) ?> value='fa-toggle-off'>toggle-off</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-on' ) ?> value='fa-toggle-on'>toggle-on</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-right' ) ?> value='fa-toggle-right'>toggle-right</option>
									<option <?php selected( $item->VM_customIcon, 'fa-toggle-up' ) ?> value='fa-toggle-up'>toggle-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-trademark' ) ?> value='fa-trademark'>trademark</option>
									<option <?php selected( $item->VM_customIcon, 'fa-train' ) ?> value='fa-train'>train</option>
									<option <?php selected( $item->VM_customIcon, 'fa-transgender' ) ?> value='fa-transgender'>transgender</option>
									<option <?php selected( $item->VM_customIcon, 'fa-transgender-alt' ) ?> value='fa-transgender-alt'>transgender-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-trash' ) ?> value='fa-trash'>trash</option>
									<option <?php selected( $item->VM_customIcon, 'fa-trash-o' ) ?> value='fa-trash-o'>trash-o</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tree' ) ?> value='fa-tree'>tree</option>
									<option <?php selected( $item->VM_customIcon, 'fa-trello' ) ?> value='fa-trello'>trello</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tripadvisor' ) ?> value='fa-tripadvisor'>tripadvisor</option>
									<option <?php selected( $item->VM_customIcon, 'fa-trophy' ) ?> value='fa-trophy'>trophy</option>
									<option <?php selected( $item->VM_customIcon, 'fa-truck' ) ?> value='fa-truck'>truck</option>
									<option <?php selected( $item->VM_customIcon, 'fa-try' ) ?> value='fa-try'>try</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tty' ) ?> value='fa-tty'>tty</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tumblr' ) ?> value='fa-tumblr'>tumblr</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tumblr-square' ) ?> value='fa-tumblr-square'>tumblr-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-turkish-lira' ) ?> value='fa-turkish-lira'>turkish-lira</option>
									<option <?php selected( $item->VM_customIcon, 'fa-tv' ) ?> value='fa-tv'>tv</option>
									<option <?php selected( $item->VM_customIcon, 'fa-twitch' ) ?> value='fa-twitch'>twitch</option>
									<option <?php selected( $item->VM_customIcon, 'fa-twitter' ) ?> value='fa-twitter'>twitter</option>
									<option <?php selected( $item->VM_customIcon, 'fa-twitter-square' ) ?> value='fa-twitter-square'>twitter-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-umbrella' ) ?> value='fa-umbrella'>umbrella</option>
									<option <?php selected( $item->VM_customIcon, 'fa-underline' ) ?> value='fa-underline'>underline</option>
									<option <?php selected( $item->VM_customIcon, 'fa-undo' ) ?> value='fa-undo'>undo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-university' ) ?> value='fa-university'>university</option>
									<option <?php selected( $item->VM_customIcon, 'fa-unlink' ) ?> value='fa-unlink'>unlink</option>
									<option <?php selected( $item->VM_customIcon, 'fa-unlock' ) ?> value='fa-unlock'>unlock</option>
									<option <?php selected( $item->VM_customIcon, 'fa-unlock-alt' ) ?> value='fa-unlock-alt'>unlock-alt</option>
									<option <?php selected( $item->VM_customIcon, 'fa-unsorted' ) ?> value='fa-unsorted'>unsorted</option>
									<option <?php selected( $item->VM_customIcon, 'fa-upload' ) ?> value='fa-upload'>upload</option>
									<option <?php selected( $item->VM_customIcon, 'fa-usd' ) ?> value='fa-usd'>usd</option>
									<option <?php selected( $item->VM_customIcon, 'fa-user' ) ?> value='fa-user'>user</option>
									<option <?php selected( $item->VM_customIcon, 'fa-user-md' ) ?> value='fa-user-md'>user-md</option>
									<option <?php selected( $item->VM_customIcon, 'fa-user-plus' ) ?> value='fa-user-plus'>user-plus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-user-secret' ) ?> value='fa-user-secret'>user-secret</option>
									<option <?php selected( $item->VM_customIcon, 'fa-user-times' ) ?> value='fa-user-times'>user-times</option>
									<option <?php selected( $item->VM_customIcon, 'fa-users' ) ?> value='fa-users'>users</option>
									<option <?php selected( $item->VM_customIcon, 'fa-venus' ) ?> value='fa-venus'>venus</option>
									<option <?php selected( $item->VM_customIcon, 'fa-venus-double' ) ?> value='fa-venus-double'>venus-double</option>
									<option <?php selected( $item->VM_customIcon, 'fa-venus-mars' ) ?> value='fa-venus-mars'>venus-mars</option>
									<option <?php selected( $item->VM_customIcon, 'fa-viacoin' ) ?> value='fa-viacoin'>viacoin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-video-camera' ) ?> value='fa-video-camera'>video-camera</option>
									<option <?php selected( $item->VM_customIcon, 'fa-vimeo' ) ?> value='fa-vimeo'>vimeo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-vimeo-square' ) ?> value='fa-vimeo-square'>vimeo-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-vine' ) ?> value='fa-vine'>vine</option>
									<option <?php selected( $item->VM_customIcon, 'fa-vk' ) ?> value='fa-vk'>vk</option>
									<option <?php selected( $item->VM_customIcon, 'fa-volume-down' ) ?> value='fa-volume-down'>volume-down</option>
									<option <?php selected( $item->VM_customIcon, 'fa-volume-off' ) ?> value='fa-volume-off'>volume-off</option>
									<option <?php selected( $item->VM_customIcon, 'fa-volume-up' ) ?> value='fa-volume-up'>volume-up</option>
									<option <?php selected( $item->VM_customIcon, 'fa-warning' ) ?> value='fa-warning'>warning</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wechat' ) ?> value='fa-wechat'>wechat</option>
									<option <?php selected( $item->VM_customIcon, 'fa-weibo' ) ?> value='fa-weibo'>weibo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-weixin' ) ?> value='fa-weixin'>weixin</option>
									<option <?php selected( $item->VM_customIcon, 'fa-whatsapp' ) ?> value='fa-whatsapp'>whatsapp</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wheelchair' ) ?> value='fa-wheelchair'>wheelchair</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wifi' ) ?> value='fa-wifi'>wifi</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wikipedia-w' ) ?> value='fa-wikipedia-w'>wikipedia-w</option>
									<option <?php selected( $item->VM_customIcon, 'fa-windows' ) ?> value='fa-windows'>windows</option>
									<option <?php selected( $item->VM_customIcon, 'fa-won' ) ?> value='fa-won'>won</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wordpress' ) ?> value='fa-wordpress'>wordpress</option>
									<option <?php selected( $item->VM_customIcon, 'fa-wrench' ) ?> value='fa-wrench'>wrench</option>
									<option <?php selected( $item->VM_customIcon, 'fa-xing' ) ?> value='fa-xing'>xing</option>
									<option <?php selected( $item->VM_customIcon, 'fa-xing-square' ) ?> value='fa-xing-square'>xing-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-y-combinator' ) ?> value='fa-y-combinator'>y-combinator</option>
									<option <?php selected( $item->VM_customIcon, 'fa-y-combinator-square' ) ?> value='fa-y-combinator-square'>y-combinator-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-yahoo' ) ?> value='fa-yahoo'>yahoo</option>
									<option <?php selected( $item->VM_customIcon, 'fa-yc' ) ?> value='fa-yc'>yc</option>
									<option <?php selected( $item->VM_customIcon, 'fa-yc-square' ) ?> value='fa-yc-square'>yc-square</option>
									<option <?php selected( $item->VM_customIcon, 'fa-yelp' ) ?> value='fa-yelp'>yelp</option>
									<option <?php selected( $item->VM_customIcon, 'fa-yen' ) ?> value='fa-yen'>yen</option>
									<option <?php selected( $item->VM_customIcon, 'fa-youtube' ) ?> value='fa-youtube'>youtube</option>
									<option <?php selected( $item->VM_customIcon, 'fa-youtube-play' ) ?> value='fa-youtube-play'>youtube-play</option>
									<option <?php selected( $item->VM_customIcon, 'fa-youtube-square' ) ?> value='fa-youtube-square'>youtube-square</option>
								</select>
							</td>
							<td>
								<span style="width: 100%; text-align: center;" class="button-secondary fontAwesomeIconAppend"><i class="fa <?php echo $item->VM_customIcon; ?>"></i></span>
							</td>
						</tr>
					</table>
				</label>
			</div>

			<?php wp_enqueue_media(); ?>

			<div class="field-custom description description-wide" style="display: <?php echo $VM_customMenuIconHide; ?>">
				<label for="menu-item-custom-img-icon[<?php echo $item_id; ?>]">
					<?php _e( 'Image Icon Upload' ); ?><br/>
					<table style="width: 100%" class="icon-bar-table-menu">
						<tr>
							<td>
								<input style="width: 100%" value="<?php echo $item->VM_customIconImg; ?>" type="url" name="menu-item-custom-img-icon[<?php echo $item_id; ?>]" id="menu-item-custom-img-icon[<?php echo $item_id; ?>]" class="widefat code edit-menu-item-custom regular-text menu_image_icon_url" placeholder="Image Icon Upload">
							</td>
							<td>
								<?php
								if ( ! empty( $item->VM_customIconImg ) ) {
									?>
									<div class="button-secondary" style="position:relative; width: 30px">
										<img style="max-width: 16px;max-height: 16px; position: absolute; top: 0; bottom: 0; left: 0; right: 0; margin: auto;" src="<?php echo $item->VM_customIconImg; ?>" alt="Icon">
									</div>
									<?php
								}
								?>
							</td>
							<td>
								<input style="width: 100%" type="button" name="upload-btn" class="button-small button-secondary menu_image_icon_url_upload" value="Upload">
							</td>
							<td>
								<i class="fa fa-times button-secondary"></i>
							</td>
						</tr>
					</table>
				</label>
			</div>

			<div class="field-custom description description-wide">
				<label class="VM_Active_DropDown" for="menu-item-custom-stay-active-dropDown[<?php echo $item_id; ?>]">
					<?php _e( 'Stay Active' ); ?>
					<select name="menu-item-custom-stay-active-dropDown[<?php echo $item_id; ?>]" id="menu-item-custom-stay-active-dropDown[<?php echo $item_id; ?>]" class="widefat code edit-menu-item-custom">
						<option <?php selected( $item->VM_custom_Active_DropDown, '' ) ?> value=""></option>
						<option <?php selected( $item->VM_custom_Active_DropDown, 'Active' ) ?> value="Active">Active</option>
					</select>
<!--					--><?php //var_dump( $item->VM_custom_Active_DropDown ); ?>
				</label>
			</div>

			<?php
			/*
			 * end added field
			 */
			?>
			<div class="menu-item-actions description-wide submitbox">
				<?php if ( 'custom' != $item->type && $original_title !== false ) : ?>
					<p class="link-to-original">
						<?php printf( __( 'Original: %s' ), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
					</p>
				<?php endif; ?>
				<a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
				echo wp_nonce_url(
					add_query_arg(
						array(
							'action'    => 'delete-menu-item',
							'menu-item' => $item_id,
						),
						remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) )
					),
					'delete-menu_item_' . $item_id
				); ?>"><?php _e( 'Remove' ); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array( 'edit-menu-item' => $item_id, 'cancel' => time() ), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
				?>#menu-item-settings-<?php echo $item_id; ?>"><?php _e( 'Cancel' ); ?></a>
			</div>

			<input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>"/>
			<input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>"/>
			<input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>"/>
			<input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>"/>
			<input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>"/>
			<input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>"/>
		</div>
		<!-- .menu-item-settings-->
		<ul class="menu-item-transport"></ul>
		<?php
		$output .= ob_get_clean();
	}
}

?>