<?php
// get options for database
$option = get_option( 'VM_database_option' );

$defaults = array(
	'theme_location'  => '',
	'menu'            => $option['menu-name'],
	'container'       => 'div',
	'container_class' => '',
	'container_id'    => '',
	'menu_class'      => 'menu',
	'menu_id'         => '',
	'echo'            => true,
	'fallback_cb'     => 'wp_page_menu',
	'before'          => '',
	'after'           => '',
	'link_before'     => '',
	'link_after'      => '',
	'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s</ul>',
	'depth'           => 0,
	'walker'          => new VM_VerticalMenu_walker_nav_menu()
);

class VM_VerticalMenu_walker_nav_menu extends Walker_Nav_Menu {

// add classes to ul sub-menus
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		// depth dependent classes
		$indent        = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent
		$display_depth = ( $depth + 1 ); // because it counts the first submenu as 0
		$classes       = array(
			'drop-down',
			( $display_depth % 2 ? 'menu-odd' : 'menu-even' ),
			( $display_depth >= 2 ? 'sub-sub-menu' : '' ),
			'menu-depth-' . $display_depth
		);
		$class_names   = implode( ' ', $classes );

		// build html
		$output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
	}

// add main/sub classes to li's and links
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
//		global $wp_query;
		$indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent

		// depth dependent classes
		$depth_classes     = array(
			( $depth == 0 ? 'main-menu-item' : 'sub-menu-item' ),
			( $depth >= 2 ? 'sub-sub-menu-item' : '' ),
			( $depth % 2 ? 'menu-item-odd' : 'menu-item-even' ),
			'menu-item-depth-' . $depth
		);
		$depth_class_names = esc_attr( implode( ' ', $depth_classes ) );

		// passed classes
		$classes     = empty( $item->classes ) ? array() : (array) $item->classes;
		$class_names = esc_attr( implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) ) );

		// active drop down
		if ( empty( $item->VM_custom_Active_DropDown ) ) {
			$active_Drop_Down = null;
		} else {
			$active_Drop_Down = 'stayActiveDropDown';
		}

		// build html
		$output .= $indent . '<li id="nav-menu-item-' . $item->ID . '" class="' . $active_Drop_Down . ' ' . $depth_class_names . ' ' . $class_names . '">';

		// link attributes
		$attributes = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
		$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';
		$attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) . '"';

		// fontAwesome icon
		if ( empty( $item->VM_customIcon ) ) {
			$icons_hide = null;
		} else {
			$icons_hide = '<i class="fa ' . $item->VM_customIcon . '"></i>';
		}

		// image icon
		if ( empty( $item->VM_customIconImg ) ) {
			$icons_hide_img = null;
		} else {
			$icons_hide_img = '<i class="VMImgIcon"><img src="' . $item->VM_customIconImg . '" alt="Icon"></i>';
		}

		// padding
		if ( empty( $item->VM_customIcon ) and empty( $item->VM_customIconImg ) ) {
			$span_padding = '15px';
		} else {
			$span_padding = '50px';
		}

		if ( $depth === 0 ) {
			$menuShow = '<span style="padding-right: ' . $span_padding . ';">' . apply_filters( 'the_title', $item->title, $item->ID ) . '</span>' . $icons_hide . $icons_hide_img . '';
		} else {
			$menuShow = '' . apply_filters( 'the_title', $item->title, $item->ID ) . '';
		}

		if ( isset( $args->before ) and isset( $args->link_before ) and isset( $args->link_after ) and isset( $args->after ) ) {
			$item_output = sprintf( '%1$s<a%2$s>%3$s%4$s%5$s</a>%6$s',
				$args->before,
				$attributes,
				$args->link_before,
				$menuShow,
				$args->link_after,
				$args->after
			);
			// build html
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}
	}
}

?>

<nav id="verticalMenu" class="verticalMenu" data-color="<?php
// check if this empty custom color
if ( isset( $option['data-color-on'] ) ) {
	if ( $option['data-color-on'] === 'true' ) {
		// predefined colors used
		echo valueSet( $option['data-color-change'], 'blue' );
	}
} ?>">
	<!--icons bar-->
	<aside class="icons-bar">

		<!-- icon bar div for menu show -->
		<div class="iconBarTrigger">
			<span></span><span></span><span></span><span></span>
		</div>

		<!-- search bar icon -->
		<a id="verticalMenuSearchIcon">
			<i class="fa fa-search"></i>
			<i class="fa fa-close"></i>
		</a>
		<!-- tooltip -->
		<?php
		if ( ! empty( $option['fontIconBar'] ) ) {
			foreach ( $option['fontIconBar'] as $count => $value ) {

				if ( ! empty( $option['fontIconBar'][ $count ] ) ) {
					?>
					<!-- icons -->
					<a <?php
					if ( ! empty( $option['iconBarTooltip'][ $count ] ) ) {
						?>
						data-tooltip="<?php echo $option['iconBarTooltip'][ $count ]; ?>"
						<?php
					}
					?>
						<?php
						if ( ! empty( $option['iconBarURL'][ $count ] ) ) {
							?>
							href="<?php echo $option['iconBarURL'][ $count ]; ?>"
							<?php
						}
						?>
					>
						<?php
						if ( ! empty( $option['fontIconBar'][ $count ] ) ) {
							?>
							<i class="fa <?php echo $option['fontIconBar'][ $count ]; ?>"></i>
							<?php
						}
						if ( ! empty( $option['iconBarImage'][ $count ] ) ) {
							?>
							<span class="imgOverlay"></span>
							<img src="<?php echo $option['iconBarImage'][ $count ]; ?>" alt="icon">
							<?php
						}
						?>
					</a>
					<?php
				}
			}
		}
		?>
		<!-- icons content -->
		<aside class="icons-bar-content <?php echo $option['menu-icon-bar-hide']; ?>">
				<span>
					<?php
					echo valueSet( $option['menu-icon-text-first'], 'VERTICAL' );
					?>
				</span>
				<span>
					<?php
					echo valueSet( $option['menu-icon-text-second'], 'NAV' );
					?>
				</span>
		</aside>
	</aside>

	<!-- search bar desktop mode -->
	<?php
	$args = array(
		'before_widget' => '<div id="verticalMenuSearchBar">',
		'after_widget'  => '</div>'
	);
	the_widget( 'WP_Widget_Search', $instance = array(), $args );
	?>

	<!-- menu bar -->
	<aside class="menu-bar">

		<!-- user profile -->
		<div class="menu-user-profile">
			<!-- user picture -->
			<figure>
				<img src="<?php echo valueSet( $option['menu-profile-image'], plugins_url( 'images/user.jpg', dirname( __FILE__ ) ) ); ?>" alt="img">
			</figure>
			<!-- profile info -->
			<h1><?php echo valueSet( $option['profile-name'], 'USER NAME' ); ?></h1>
			<h4><?php echo valueSet( $option['profile-description'], 'Web Designer' ); ?></h4>
		</div>

		<!-- list items php -->
		<ul class="menu-list-items">
			<?php
			wp_nav_menu( $defaults );
			?>
		</ul>

		<!-- footer -->
		<div class="menu-footer <?php echo $option['menu-footer-hide']; ?>">
			<?php
			echo valueSet( $option['menu-footer-text'], '&commat; 20014 - 2015 vNav' );
			?>
		</div>
	</aside>
</nav>