<?php

/*
Plugin Name: Vertical Dashboard
Plugin URI: 'http://w3layoutsdesigns.com'
Description: This is vertical dashboard navigation responsive menu.
Version: 2.0
Author: thebestdesigns
Author URI: http://w3layoutsdesigns.com
License: A "Slug" license name e.g. GPL2
*/

// default registration values
register_activation_hook( __FILE__, 'VM_default_register_values' );

function VM_default_register_values() {

	// default array values
	$VM_default_values = array(
		'menu-name'                     => '',
		'menu-bar-auto-add'             => 'true',
		'menu-bar-show'                 => 'true',
		'menu-bar-width'                => '240',
		'menu-bar-show-speed'           => '400',
		'menu-bar-effect'               => 'slide',
		'outside-click-hide-menu'       => 'true',
		'auto-hide-menu'                => 'false',
		'auto-hide-menu-speed'          => '1000',
		'drop-down-trigger'             => 'click',
		'drop-down-speed'               => '400',
		'drop-down-icons-radius'        => '0',
		'auto-hide-drop-down'           => 'false',
		'auto-hide-drop-down-speed'     => '200',
		'outside-click-hide-dropDown'   => 'true',
		'hide-other-dropDowns-on-click' => 'true',
		'menu-transparent'              => '0',
		'responsive'                    => 'true',
		'search-bar-show'               => 'true',
		'menu-footer-text'              => '',
		'menu-footer-hide'              => '',
		'menu-icon-text-first'          => '',
		'menu-icon-text-second'         => '',
		'menu-icon-bar-hide'            => '',
		'menu-profile-image'            => '',
		'profile-show-desktop'          => 'false',
		'profile-name'                  => '',
		'profile-description'           => '',
		'scroll-bar-always-hide'        => 'true',
		'scroll-bar-auto-hide'          => 'true',
		'scroll-bar-arrow-show'         => 'true',
		'scroll-bar-auto-expand'        => 'false',
		'scroll-amount'                 => '100',
		'search-bar-show-mobile'        => 'true',
		'mobile-fixed-menu'             => 'true',
		'mobile-profile-show'           => 'true',
		'mobile-collapse'               => 'true',
		'collapse-title'                => '',
		'collapse-URL'                  => '',
		'icons-bar-border-radius'       => '0',
		'data-color-change'             => 'blue',
		'data-color-on'                 => 'true',
		'custom-color-on'               => 'false',
		'menu-custom-css'               => '',
	);

	// get the options from database
	$option = wp_parse_args( get_option( 'VM_database_option' ), $VM_default_values );

	// update values
	update_option( 'VM_database_option', $option );

}

// create custom plugin settings for menu
add_action( 'admin_menu', 'VM_admin_options' );

function VM_admin_options() {
	//create new top-level menu
	add_menu_page( 'Plugin Settings', 'Vertical Menu Settings', 'administrator', __FILE__, 'VM_settings_page' );
	//call register settings function
	add_action( 'admin_init', 'VM_register_settings' );
}


function VM_register_settings() {
	//register our settings
	register_setting( 'VM-settings-group', 'VM_database_option' );
}

// settings create
function VM_settings_page() {
	?>
	<div class="wrap verticalMenuAdmin">
		<h3>Vertical Menu Options</h3>
		<?php
		// require file
		require_once 'include/extra.php';
		// option
		if ( defined( 'DISABLE_OPTION' ) ) {
			?>
			<h4>
				Get full features
				<a target="_blank" style="color: orangered" href="http://w3layoutsdesign.com/shop/vertical-dashboard-navigation-wordpress/">Upgrade to Vertical Menu Premium</a>
			</h4>
			<?php
		}
		?>
		<!-- options file -->
		<?php require 'include/admin_options.php'; ?>
	</div>
	<?php
}

// import setting function
function VM_import_setting_insert() {

	// verify
	if ( isset( $_POST['VM_importSettings'] ) ) {
		if ( ! wp_verify_nonce( $_POST['VM_importSettings'], 'VM_importSettings' ) ) {
			return;
		}
	}

	if ( isset( $_POST['VM_import_setting'] ) ) {
		// get the import setting from textarea
		$import_file = $_POST['VM_import_setting'];
		// check if the textarea is empty
		if ( empty( $import_file ) ) {
			// error
			wp_die( 'Input field is empty' );
		}
		// decode settings base64
		$base64Decode = base64_decode( $import_file );
		// check if the data serialize
		if ( is_serialized( $base64Decode ) ) {
			// un serialize data
			$settings = unserialize( $base64Decode );
			// update settings to database
			update_option( 'VM_database_option', $settings );
		} else {
			// error
			wp_die( 'Your Data is not Correct' );
		}
	}
}

// add settings on admin panel
add_action( 'admin_init', 'VM_import_setting_insert' );

// get the options from database
$option_menu = get_option( 'VM_database_option' );
// menu bar show auto add button
if ( isset( $option_menu['menu-bar-auto-add'] ) and $option_menu['menu-bar-auto-add'] === 'true' ) {

	// show the HTML menu on user frontend
	function VM_menu_frontend_show() {
		ob_start();

		// get menu frontend for
		require 'include/menu_frontend.php';

		$html = ob_get_clean();

		echo $html;
	}

	add_action( 'wp_footer', 'VM_menu_frontend_show' );

} else {

	// show the HTML menu using shortcode
	function VM_menu_frontend_show_shortcode() {
		ob_start();

		// get menu frontend for
		require 'include/menu_frontend.php';

		$html = ob_get_clean();

		echo $html;
	}

	add_shortcode( 'VM_Vertical_Menu_Shortcode', 'VM_menu_frontend_show_shortcode' );

}

// register scripts and styles for user panel
function VM_styles_and_scripts() {
	// normalize for css reset
	wp_register_style( 'VM_normalize', plugins_url( 'css/normalize.min.css', __FILE__ ) );
	wp_enqueue_style( 'VM_normalize' );
	// custom scroll bar
	wp_register_style( 'VM_customScrollBar', plugins_url( 'css/custom_scrollbar.css', __FILE__ ) );
	wp_enqueue_style( 'VM_customScrollBar' );
	// font awesome css for icons
	wp_register_style( 'VM_fontAwesome', plugins_url( 'css/font-awesome.min.css', __FILE__ ) );
	wp_enqueue_style( 'VM_fontAwesome' );
	// vertical menu style css
	wp_register_style( 'VM_style', plugins_url( 'css/verticalMenu.css', __FILE__ ) );
	wp_enqueue_style( 'VM_style' );

	// inline css apply file
	require 'include/inline-style.php';

	// custom scroll bar script
	wp_register_script( 'VM_customScrollBarScript', plugins_url( 'js/custom-scrollBar.min.js', __FILE__ ), array( 'jquery' ) );
	wp_enqueue_script( 'VM_customScrollBarScript' );

	// match media script
	wp_register_script( 'VM_matchMediaScript', plugins_url( 'js/matchMedia.min.js', __FILE__ ), array( 'jquery' ) );
	wp_enqueue_script( 'VM_matchMediaScript' );

	// vertical menu script
	wp_register_script( 'VM_vertical_menu_script', plugins_url( 'js/verticalMenu.min.js', __FILE__ ), array(
		'jquery-effects-slide',
		'jquery-effects-blind',
		'jquery-effects-drop',
		'jquery-effects-fade',
		'jquery-effects-fold',
		'jquery-effects-puff',
		'jquery'
	) );

	// get the options from database
	$option = get_option( 'VM_database_option' );

	// default value set function
	require 'include/default-values.php';

	// verticalMenu js file options change
	$verticalMenuOptions = array(
		'menu_bar_show'                  => $option['menu-bar-show'],                    // true
		'menu_bar_show_speed'            => $option['menu-bar-show-speed'],              // 200
		'menu_bar_effect'                => $option['menu-bar-effect'],                  // slide
		'outside_click_hide_menu'        => $option['outside-click-hide-menu'],          // true
		'auto_hide_on'                   => $option['auto-hide-menu'],                   // true
		'auto_hide_menu_speed'           => $option['auto-hide-menu-speed'],             // undefined
		'auto_hide_drop_down_on'         => $option['auto-hide-drop-down'],              // true
		'auto_hide_drop_down_speed'      => $option['auto-hide-drop-down-speed'],        // undefined
		'drop_down_trigger'              => $option['drop-down-trigger'],                // click
		'drop_down_showing_speed'        => $option['drop-down-speed'],                  // 200
		'outside_click_hide_dropDown'    => $option['outside-click-hide-dropDown'],      // true
		'hide_others_dropDowns_on_click' => $option['hide-other-dropDowns-on-click'],    // true
		'fixed_menu'                     => 'true',
		'user_profile_show'              => $option['profile-show-desktop'],             // false
		'transparent'                    => $option['menu-transparent'],                 // undefined
		'scroll_bar_always_hide'         => $option['scroll-bar-always-hide'],           // false
		'scroll_bar_auto_hide'           => $option['scroll-bar-auto-hide'],             // true
		'scroll_amount'                  => valueSet( $option['scroll-amount'], '100' ), // 100
		'scroll_bar_button_show'         => $option['scroll-bar-arrow-show'],            // This option used for show the scroll bar arrow up and down button. option (true) or (false).
		'scroll_bar_auto_expand'         => $option['scroll-bar-auto-expand'],           // This option used for auto expand the scroll bar on mouse hover. option (true) or (false).
		'responsive'                     => $option['responsive'],                       // true
		'search_bar_show'                => $option['search-bar-show'],                  // true
		// mobile settings
		'fixed_menu_mobile'              => $option['mobile-fixed-menu'],                // false
		'user_profile_show_mobile'       => $option['mobile-profile-show'],              // false
		'collapse_mobile'                => $option['mobile-collapse'],                  // true
		'collapse_title'                 => $option['collapse-title'],                   // menu
		'collapse_url'                   => $option['collapse-URL'],                     // URL
		'search_bar_show_mobile'         => $option['search-bar-show-mobile']            // true
	);

	wp_localize_script( 'VM_vertical_menu_script', 'verticalMenuOption', $verticalMenuOptions );
	wp_enqueue_script( 'VM_vertical_menu_script' );

}

add_action( 'wp_enqueue_scripts', 'VM_styles_and_scripts' );

// register scripts and styles for admin panel
function VM_admin_styles_and_scripts() {

	// bootstrap css for grid system
	wp_register_style( 'VM_admin_bootstrap', plugins_url( 'css/bootstrap.min.css', __FILE__ ) );
	wp_enqueue_style( 'VM_admin_bootstrap' );
	// vertical menu admin css
	wp_register_style( 'VM_admin_panel', plugins_url( 'css/admin.css', __FILE__ ) );
	wp_enqueue_style( 'VM_admin_panel' );
	// bootstrap script
	wp_register_script( 'VM_admin_bootstrap_script', plugins_url( 'js/bootstrap.min.js', __FILE__ ), array( 'jquery' ), '3.3.5', true );
	wp_enqueue_script( 'VM_admin_bootstrap_script' );
	// Add the color picker css file
	wp_enqueue_style( 'wp-color-picker' );
	// admin script
	wp_register_script( 'VM_admin_script', plugins_url( 'js/admin.min.js', __FILE__ ), array(
		'jquery',
		'wp-color-picker',
		'jquery-ui-sortable',
		'jquery-form'
	), false, true );
	wp_enqueue_script( 'VM_admin_script' );
	// font awesome css for icons
	wp_register_style( 'VM_admin_fontAwesome', plugins_url( 'css/font-awesome.min.css', __FILE__ ) );
	wp_enqueue_style( 'VM_admin_fontAwesome' );

}

add_action( 'admin_menu', 'VM_admin_styles_and_scripts' );


// custom menu admin fields
require 'include/custom-admin-menu-fields.php';

// Live color picker
require 'include/color-picker.php';

// inline color css
require 'include/inline-color.php';