(function ($) {

    // default settings
    'use strict';
    var defaultSettings = {
        menu_bar_show                 : true,           //- This option show the menu bar. Options (true) or (false)
        menu_bar_show_speed           : 200,            //- This is menu bar show and hide speed. Speed in milliseconds
        menu_bar_effect               : 'slide',        //- This option used for change the menu show effects. Total 6 effects (slide), (blind), (drop), (fade), (fold), (puff).
        outside_click_hide_menu       : true,           //- This option used for hide the showing menu bar when click outside the menu. Options (true) or (false). Note: This option works if (menu_bar_show) option true. or below option (auto_hide_menu_speed) not work if this option true.
        auto_hide_menu_speed          : undefined,      //- This option used for auto hide the menu bar. Option used integer value or value in milliseconds. Note: This option not work if above option (outside_click_hide_menu) true. Or set option to (undefined) disable the auto hide.
        drop_down_trigger             : 'click',        //- drop down trigger change. options (click) or (hover)
        drop_down_showing_speed       : 200,            //- drop down showing or hiding speed. Speed in milliseconds
        drop_down_auto_hide           : undefined,      //- This option used for auto hide the drop down
        outside_click_hide_dropDown   : false,          //- This option used for hide the showing drop downs when click outside the menu . Options (true) or (false)
        hide_others_dropDowns_on_click: true,           //- This option used for hide the other showing drop downs when click on current drop down. Options (true) or (false)
        fixed_menu                    : true,           //- This option fixed the menu top left side of the screen. Options (true) or (false)
        user_profile_show             : false,          //- This option show the user profile. Options (true) or (false)
        transparent                   : undefined,      //- This option used for transparent the menu. Option Value in integer (0 to 1) or undefined to disable the transparent. Example (0.5), (0.8) etc.
        scroll_bar_always_hide        : false,          //- This option used for always hide the scroll bar. Options (true) or (false).
        scroll_bar_auto_hide          : true,           //- This option used for auto hide the scroll bar. Options (true) or (false).
        scroll_amount                 : 100,            //- This options used for scrolling amount. Options in integer value.
        scroll_bar_button_show        : true,           //- This option used for show the scroll bar arrow up and down button. option (true) or (false).
        scroll_bar_auto_expand        : false,          //- This option used for auto expand the scroll bar on mouse hover. option (true) or (false).
        responsive                    : true,           //- This option make menu responsive or not. Options (true) or (false). Note: mobiles settings not work if this option false.
        search_bar_show               : true,           //- This option used for show or hide the search bar
        search_bar_auto_hide          : undefined,      //- This option auto hide the search bar if the (auto_hide_menu_speed) is set.
        // mobile mode settings
        mobile                        : {
            fixed_menu       : false,                   //- This option fixed the menu top left side of the screen. Options (true) or (false)
            user_profile_show: false,                   //- This option show the user profile. Options (true) or (false)
            collapse         : true,                    //- This option hide the menu on mobile mode or click to show the menu on mobile mode. Options (true) or (false)
            collapse_title   : '<a href="#">MENU</a>',  //- This is collapse title
            search_bar_show  : true                     //- This option used for show or hide the search bar on mobile view
        },
        // media query max width
        media_query_width             : 767             //- This is media query max width. Don't edit if you don't know about this.
    };

    $.fn.verticalMenu = function (settings) {
        settings = $.extend({}, defaultSettings, settings || {});
        return this.each(function () {
            // variables
            /*global jQuery*/
            var $this = $(this),
                $a = 'a',
                $li = 'li',
                icon_bar = $this.find('.icons-bar'),
                menu_bar = $this.find('.menu-bar'),
                user_profile = menu_bar.find('.menu-user-profile'),
                icon_bar_trigger = '.iconBarTrigger',
                drop_down_indicator = '.dropDownIndicator',
                mobile_collapse_button = '.menuCollapseButton',
                list_items = menu_bar.find('.menu-list-items'),
                drop_down = list_items.find('.drop-down'),
                list_items_active = 'activeClick',
                active_class = 'active',
                menuResponsive = 'responsive',
                withoutResponsive = 'menuFixedResponsive',
                fixed_menu = 'menuFixed',
                htmlMenuFixed = 'verticalMenuFixed',
                htmlMenuFixedMobile = 'verticalMenuFixedMobile',
                searchBarIcon = $this.find('#verticalMenuSearchIcon'),
                searchBarContainer = $this.find('#verticalMenuSearchBar'),
                HTML = 'html',
                Canvas,
                auto_hide,
                auto_hide_drop_down,
                auto_hide_search_bar,
                $object;

            // Class
            Canvas = (function () {

                //------------------------------------------------------------------------------------------------- constructor
                //noinspection JSLint
                function Canvas(name) {
                    this.name = name;
                }

                // ------------------------------------------------------------------------------------- menu bar show function

                Canvas.prototype.Menu_Bar_show = function (desktop) {

                    // search bar hide function
                    var Menu_Bar_Show_Click, searchBarHide;

                    searchBarHide = function () {
                        // check if the desktop view
                        if (desktop === true) {
                            // search bar hide
                            searchBarContainer.hide(settings.menu_bar_effect, settings.menu_bar_show_speed);
                            searchBarIcon.find('.fa-close').stop(true, true).fadeOut(settings.menu_bar_show_speed, function () {
                                searchBarIcon.find('.fa-search').stop(true, true).fadeIn(settings.menu_bar_show_speed);
                            });
                        }
                    };

                    // check if the menu_bar_show option is true then hide the menu bar
                    if (settings.menu_bar_show === true) {

                        // check if the desktop view
                        if (desktop === true) {

                            // hide the menu bar by adding a hide class on desktop mode
                            menu_bar.hide(0);
                            // show the icon bar trigger on desktop view
                            icon_bar.find(icon_bar_trigger).show(0);

                        }

                        // menu bar show function trigger when click on icon bar
                        Menu_Bar_Show_Click = function (event, current) {

                            // stop default behaviour
                            event.preventDefault();
                            event.stopPropagation();
                            event.stopImmediatePropagation();

                            // this variable
                            current = $(this);

                            // check if the desktop mode then run this code
                            if (desktop === true) {

                                // check if the menu bar is hidden
                                if (menu_bar.is(':hidden')) {

                                    // menu bar show
                                    menu_bar.stop(true, true).show(settings.menu_bar_effect, settings.menu_bar_show_speed, function () {

                                        // call back function
                                        // add active class on icon bar
                                        current.addClass(active_class);

                                        // add click event again after menu bar show
                                        current.one('click', Menu_Bar_Show_Click);

                                    });

                                    // call search bar hide function
                                    searchBarHide();

                                    // else if the menu bar is visible
                                } else {

                                    // menu bar hide
                                    menu_bar.stop(true, true).hide(settings.menu_bar_effect, settings.menu_bar_show_speed, function () {

                                        // call back function
                                        // remove active class on icon bar
                                        current.removeClass(active_class);

                                        // add click event again after menu bar hide
                                        current.one('click', Menu_Bar_Show_Click);

                                    });

                                }

                            }

                        };

                        // add the click trigger on icon bar and show the menu bar
                        icon_bar.find(icon_bar_trigger).one('click', Menu_Bar_Show_Click);

                    }

                };

                //----------------------------------------------------------------------------------------- menu fixed function
                Canvas.prototype.Menu_Fixed = function (flag) {
                    // check if the fixed menu true
                    if (flag === true && settings.fixed_menu === true) {
                        // add class menuFixed on desktop mode
                        $this.addClass(fixed_menu);
                        // add padding if menu bar show false
                        if (settings.menu_bar_show === false) {
                            // add padding on html for fixed menu
                            $(HTML).addClass(htmlMenuFixed);
                        }
                        // remove padding on html for fixed menu
                        $(HTML).removeClass(htmlMenuFixedMobile);
                    } else if (flag === false && settings.mobile.fixed_menu === true) {
                        // add class menuFixed on mobile mode
                        $this.addClass(fixed_menu);
                        // add padding on html for fixed menu
                        $(HTML).addClass(htmlMenuFixedMobile);
                        // remove padding on html for fixed menu
                        $(HTML).removeClass(htmlMenuFixed);
                    } else {
                        // remove class
                        $this.removeClass(fixed_menu);
                        // remove padding on html for fixed menu
                        $(HTML).removeClass(htmlMenuFixed).removeClass(htmlMenuFixedMobile);
                    }
                };

                //----------------------------------------------------------------------------------------- responsive function
                Canvas.prototype.Menu_Responsive = function () {
                    // check if the responsive true
                    if (settings.responsive === true) {
                        // add responsive class
                        $this.addClass(menuResponsive);
                    } else if (settings.responsive === false && settings.fixed_menu === true) {
                        // add class menu fixed without responsive
                        $this.addClass(withoutResponsive);
                    }
                };

                //--------------------------------------------------------------------------- mobile view collapse bar function
                Canvas.prototype.Mobile_Collapse = function (desktop) {

                    // search bar hide function
                    var searchBarHide = function () {
                        // check if the desktop view
                        if (desktop === false) {
                            // search bar mobile icon
                            var searchBarIconMobile = $this.find('#verticalMenuSearchIconMobile');
                            // search bar hide
                            searchBarContainer.hide(0);
                            searchBarIconMobile.find('.fa-close').fadeOut(0, function () {
                                searchBarIconMobile.find('.fa-search').stop(true, true).fadeIn(0);
                            });
                        }
                    };

                    // check if the not desktop view. On mobile view
                    if (desktop === false) {
                        // check if the mobile collapse is true
                        if (settings.mobile.collapse === true) {
                            // check if the mobile collapse button not have
                            if ($this.find(mobile_collapse_button).length === 0) {
                                // append the collapse button
                                $this.prepend('<div class="menuCollapseButton">\n    ' + settings.mobile.collapse_title + '\n    <!-- search bar icons -->\n    <a id="verticalMenuSearchIconMobile">\n        <i class="fa fa-search"></i>\n        <i class="fa fa-close"></i>\n    </a>\n    <!-- collapse button icon -->\n    <div class="collapseButtonIcon">\n        <div class="collapseButtonInner">\n            <span></span>\n            <span></span>\n            <span></span>\n            <span></span>\n        </div>\n    </div>\n</div>')
                                    // apply css
                                    .css('marginTop', '50px');
                            }

                            // hide the icon bar and menu bar
                            icon_bar.add(menu_bar).hide(0);

                            // add click trigger
                            $this.find('.collapseButtonIcon').off('click').on('click', function (event, elem) {
                                event.stopPropagation();
                                event.stopImmediatePropagation();
                                // variable
                                elem = icon_bar.add(menu_bar);
                                // check if the icon bar or menu bar is hidden
                                if (elem.is(':hidden')) {

                                    // fade in
                                    elem.fadeIn(0);

                                    // call search bar hide
                                    searchBarHide();

                                } else {
                                    // fade out
                                    elem.fadeOut(0);
                                }
                            });
                        }

                        // check if the mobile collapse is false
                        else {

                            // check if the search bar show option is true on mobile view
                            if (settings.mobile.search_bar_show === true) {

                                // show the search bar icon
                                searchBarIcon.show(0);

                            }

                        }

                    }

                };

                //----------------------------------------------------------------------------------- transparent menu function
                Canvas.prototype.Transparent_Menu = function () {
                    // check if transparent is number
                    if (typeof (settings.transparent) === 'number') {
                        // apply css
                        $this.css('opacity', settings.transparent);
                    }
                };

                //-------------------------------------------------------------------------------- drop down indicator function
                Canvas.prototype.Drop_Down_Indicator = function () {
                    // check if the drop down indicator not have then append div
                    if ($this.find(drop_down_indicator).length === 0) {
                        // append drop down indicator
                        drop_down.prev($a).append('<div class="dropDownIndicator"></div>');
                    }
                    // show drop down indicator on top level or the menu if icons not have
                    drop_down.prev($a).each(function (current) {
                        current = jQuery(this);
                        if (current.children('i.fa').length === 0) {
                            current.children('.dropDownIndicator').show(0);
                        }
                    });
                };

                //--------------------------------------------------------------------------------------- user profile function
                Canvas.prototype.User_Profile = function (flag) {
                    // check if user profile show true
                    if (flag === true && settings.user_profile_show === true) {
                        // show the user profile
                        $this.find(user_profile).show(0);
                        list_items.css('top', '280px');
                    } else if (flag === false && settings.mobile.user_profile_show === true) {
                        // show the user profile
                        $this.find(user_profile).show(0);
                        list_items.css('top', '280px');
                    } else {
                        // flag false
                        // show the user profile
                        $this.find(user_profile).hide(0);
                        list_items.css('top', '0');
                    }
                };

                //---------------------------------------------------------------------------------- custom scroll bar function
                Canvas.prototype.Custom_Scroll_Bar = function (flag) {
                    // check if the flag true
                    if (flag === true) {
                        // add the custom scroll bar on menu list items
                        //noinspection SpellCheckingInspection
                        $(list_items).mCustomScrollbar({
                            // scroll bar auto hide setting
                            autoHideScrollbar  : settings.scroll_bar_auto_hide,
                            // scroll bar auto calculate drag length
                            autoDraggerLength  : true,
                            // scroll bar height 100%
                            //setHeight          : '100%',
                            // scroll bar buttons Show or hide
                            scrollButtons      : {enable: settings.scroll_bar_button_show},
                            // scroll bar width expand on mouse over
                            autoExpandScrollbar: settings.scroll_bar_auto_expand,
                            // scroll amount
                            mouseWheel         : {scrollAmount: settings.scroll_amount}
                        });
                        // scroll bar disable not show if this setting true
                        if (settings.scroll_bar_always_hide === true) {
                            // add class scroll bar hide
                            $this.addClass('scrollBarHide');
                        }
                    } else {
                        // flag false
                        // scroll bar completely destroy. show the default scroll bar
                        $(list_items).mCustomScrollbar('destroy');
                    }
                };

                //------------------------------------------------------------------------------------- drop down trigger click
                Canvas.prototype.Drop_Down_Trigger_Click = function (desktop) {

                    // click function for both desktop view and mobile view
                    var click_function = function () {

                        // add the click trigger
                        drop_down.prev($a).on('click', function (event, elem, hidden) {
                            // stop click bubbling
                            event.stopPropagation();
                            event.stopImmediatePropagation();
                            // variable
                            elem = $(this).next(drop_down);
                            hidden = elem.is(':hidden');
                            // hide the other drop downs on click if this setting true
                            if (settings.hide_others_dropDowns_on_click === true) {
                                if (hidden) {
                                    elem.parents($li).siblings($li).removeClass(list_items_active);
                                    elem.parents($li).siblings($li).find($li).removeClass(list_items_active);
                                    elem.parents($li).siblings($li).find(drop_down).slideUp(
                                        // drop down hiding speed
                                        settings.drop_down_showing_speed
                                    );
                                } else {
                                    elem.parent($li).find($li).removeClass(list_items_active);
                                    elem.parent($li).find(drop_down).slideUp(
                                        // drop down hiding speed
                                        settings.drop_down_showing_speed
                                    );
                                }
                            }
                            // check if the drop down is hidden
                            if (hidden) {
                                // add class active on list elements
                                elem.parent($li).addClass(list_items_active);
                                // slide down drop down
                                elem.slideDown(
                                    // drop down showing speed
                                    settings.drop_down_showing_speed
                                );
                            } else {
                                // remove class active on list elements
                                elem.parent($li).removeClass(list_items_active);
                                // slide up drop down
                                elem.slideUp(
                                    // drop down hiding speed
                                    settings.drop_down_showing_speed
                                );
                            }
                        });

                    };

                    // check if the desktop view
                    if (desktop === true) {
                        // check if the drop down trigger is click
                        if (settings.drop_down_trigger === 'click') {

                            // call click function for desktop view
                            click_function();

                        }
                    }

                    // check if the mobile view
                    else {

                        // check if the drop down trigger is click or hover
                        if (settings.drop_down_trigger === 'click' || settings.drop_down_trigger === 'hover') {

                            // call click function for mobile view
                            click_function();

                        }

                    }

                };

                //------------------------------------------------------------------------------------- drop down trigger hover
                Canvas.prototype.Drop_Down_Trigger_Hover = function (desktop) {

                    // check if the desktop view
                    if (desktop === true) {

                        // check if the drop down trigger is hover
                        if (settings.drop_down_trigger === 'hover') {

                            // add drop down hover function
                            drop_down.parent($li).on({
                                // mouse enter
                                'mouseenter': function () {
                                    // drop down slide down
                                    jQuery(this).children('.drop-down').stop(true, true).delay(400).slideDown(
                                        // drop down showing speed
                                        settings.drop_down_showing_speed
                                    );
                                },
                                // mouse leave
                                'mouseleave': function () {
                                    // drop down slide up
                                    jQuery(this).children('.drop-down').stop(true, true).delay(400).slideUp(
                                        // drop down hiding speed
                                        settings.drop_down_showing_speed
                                    );
                                }
                            });

                        }

                    }

                };

                //----------------------------------------------------------------------------------------- search bar function
                Canvas.prototype.Search_Bar = function (desktop) {

                    // search bar mobile icon
                    var searchBarEffect, searchBarIconMobile, menuBarHide, searchBarFunction;

                    searchBarIconMobile = $this.find('#verticalMenuSearchIconMobile');

                    // check if the desktop view
                    if (desktop === true) {

                        // menu bar show speed set default on desktop view
                        searchBarEffect = settings.menu_bar_show_speed;

                        // search bar show on desktop view
                        if (settings.search_bar_show === false) {
                            // hide the search bar icon
                            searchBarIcon.hide(0);
                        }

                    } // check if the mobile view
                    else {

                        // menu bar show speed set 0 on mobile view
                        searchBarEffect = 10;

                        // search bar show on mobile view
                        if (settings.mobile.search_bar_show === false) {
                            // hide the search bar icon
                            searchBarIconMobile.hide(0);
                        }

                    }

                    // hide the menu bar if search bar is show
                    menuBarHide = function () {

                        // check if the desktop view
                        if (desktop === true) {

                            // check if the menu bar show option is true
                            if (settings.menu_bar_show === true) {
                                // menu bar hide
                                menu_bar.stop(true, true).hide(settings.menu_bar_effect, settings.menu_bar_show_speed, function () {

                                    // call back function
                                    // remove active class on icon bar
                                    $this.find(icon_bar_trigger).removeClass(active_class);

                                });
                            }

                            // check if the mobile view
                        } else {

                            // check if the collapse option is true
                            if (settings.mobile.collapse === true) {

                                // menu bar hide
                                menu_bar.stop(true, true).hide(0, function () {

                                    // call back function
                                    // remove active class on icon bar
                                    $this.find(icon_bar_trigger).removeClass(active_class);
                                    // hide the icon bar
                                    icon_bar.hide(0);

                                });
                            }

                            // check if the collapse option is false
                            else {
                                searchBarContainer.css({
                                    'paddingLeft': '50px'
                                });
                            }

                        }
                    };

                    // search bar function
                    searchBarFunction = function (current) {
                        // this variable
                        current = $(this);
                        // check if the search bar is hidden
                        if (searchBarContainer.is(':hidden')) {
                            // hide the search bar
                            current.find('.fa-search').stop(true, true).fadeOut(searchBarEffect, function () {
                                // show the close button
                                current.find('.fa-close').stop(true, true).fadeIn(searchBarEffect);
                                // search bar show
                                searchBarContainer.show(settings.menu_bar_effect, searchBarEffect);
                            });
                            // add click function
                            searchBarIcon.add(searchBarIconMobile).one('click', searchBarFunction);

                            // call the menu bar hide function
                            menuBarHide();
                        }

                        // else
                        else {
                            // hide the close button
                            current.find('.fa-close').stop(true, true).fadeOut(searchBarEffect, function () {
                                // show the search bar
                                current.find('.fa-search').stop(true, true).fadeIn(searchBarEffect);
                                // add click function
                                searchBarIcon.add(searchBarIconMobile).one('click', searchBarFunction);
                            });
                            // search bar hide
                            searchBarContainer.hide(settings.menu_bar_effect, searchBarEffect);
                        }

                    };
                    // add click function
                    searchBarIcon.add(searchBarIconMobile).one('click', searchBarFunction);

                };

                //--------------------------------------------------------------------------------- outside click hide function
                Canvas.prototype.Outside_Click_Hide = function (desktop) {

                    // check if the desktop view
                    if (desktop === true) {

                        // add click event on document for close the menu elements
                        $(document).on('click', function (event) {

                            // check if the outside click hide menu option is true and menu bar show is true
                            if (settings.outside_click_hide_menu === true && settings.menu_bar_show === true) {

                                // check if the mouse not on menu and menu bar is visible
                                if (!$this.is(event.target) && $this.has(event.target).length === 0 && menu_bar.is(':visible')) {

                                    // menu bar hide
                                    menu_bar.stop(true, true).hide(settings.menu_bar_effect, settings.menu_bar_show_speed, function () {
                                        // call back function
                                        // remove active class
                                        icon_bar.find(icon_bar_trigger).removeClass(active_class);
                                    });

                                }

                            }

                            // check if the outside click hide drop down option is true and drop down trigger option is click
                            if (settings.outside_click_hide_dropDown === true && settings.drop_down_trigger === 'click') {

                                // check if the mouse not on menu and drop down is visible
                                if (!$this.is(event.target) && $this.has(event.target).length === 0 && drop_down.is(':visible')) {
                                    // remove the active class on list items
                                    list_items.find($li).removeClass(list_items_active);
                                    // dro down slide up
                                    drop_down.slideUp(
                                        // drop down hiding speed
                                        settings.drop_down_showing_speed
                                    );
                                }

                            }

                            // check if the outside click hide menu is true and search bar show option is true
                            if (settings.outside_click_hide_menu === true && settings.search_bar_show === true) {

                                // check if the mouse not on the menu and search bar is visible
                                if (!$this.is(event.target) && $this.has(event.target).length === 0 && searchBarContainer.is(':visible')) {
                                    // hide the close button
                                    searchBarIcon.find('.fa-close').stop(true, true).fadeOut(settings.menu_bar_show_speed, function () {
                                        // show the search bar
                                        searchBarIcon.find('.fa-search').stop(true, true).fadeIn(settings.menu_bar_show_speed);
                                    });
                                    // search bar hide
                                    searchBarContainer.hide(settings.menu_bar_effect, settings.menu_bar_show_speed);
                                }

                            }

                        });

                    }

                };

                //----------------------------------------------------------------------------------------- auto hide function
                Canvas.prototype.Auto_Hide = function (desktop) {

                    // check if the desktop view and auto hide menu speed is not undefined
                    if (desktop === true) {

                        // add mouseenter or mouseleave
                        $this.on({
                            // mouse enter clear time out
                            'mouseenter': function () {
                                // clear time out
                                clearTimeout(auto_hide);
                                clearTimeout(auto_hide_drop_down);
                                clearTimeout(auto_hide_search_bar);
                            },
                            // mouse leave trigger set time out function
                            'mouseleave': function () {

                                // check if the menu bar show option is true -----------------------------------------------
                                if (settings.menu_bar_show === true && menu_bar.is(':visible') && !(settings.auto_hide_menu_speed === undefined)) {

                                    // set time out function
                                    auto_hide = setTimeout(function () {

                                        // menu bar hide with animation
                                        menu_bar.stop(true, true).hide(settings.menu_bar_effect, settings.menu_bar_show_speed, function () {
                                            // call back function
                                            // remove the active class
                                            icon_bar.find(icon_bar_trigger).removeClass(active_class);
                                        });

                                        // speed
                                    }, settings.auto_hide_menu_speed);
                                }


                                // check if the drop down auto hide option is true -----------------------------------------
                                if (settings.drop_down_trigger === 'click' && drop_down.is(':visible') && !(settings.drop_down_auto_hide === undefined)) {

                                    // set time out function
                                    auto_hide_drop_down = setTimeout(function () {

                                        // remove the active class on list items
                                        list_items.find($li).removeClass(list_items_active);
                                        // dro down slide up
                                        drop_down.slideUp(
                                            // drop down hiding speed
                                            settings.drop_down_showing_speed
                                        );

                                        // speed
                                    }, settings.drop_down_auto_hide);
                                }


                                // check if the search bar auto hide option is true ----------------------------------------
                                if (searchBarContainer.is(':visible') && !(settings.search_bar_auto_hide === undefined)) {

                                    // set time out function
                                    auto_hide_search_bar = setTimeout(function () {

                                        // hide the close button
                                        searchBarIcon.find('.fa-close').stop(true, true).fadeOut(settings.menu_bar_show_speed, function () {
                                            // show the search bar
                                            searchBarIcon.find('.fa-search').stop(true, true).fadeIn(settings.menu_bar_show_speed);
                                        });
                                        // search bar hide
                                        searchBarContainer.hide(settings.menu_bar_effect, settings.menu_bar_show_speed);

                                        // speed
                                    }, settings.search_bar_auto_hide);
                                }


                            }
                        });

                    }
                };

                //-------------------------------------------------------------------------------------------- destroy function
                Canvas.prototype.Destroy = function () {

                    // menu bar
                    menu_bar.show(0);
                    icon_bar.find(icon_bar_trigger).off('click').removeClass(active_class).hide(0);

                    // mobile collapse
                    $this.find('.collapseButtonIcon').off('click');
                    $this.find(mobile_collapse_button).detach();
                    $this.css('marginTop', '');
                    icon_bar.add(menu_bar).show(0);

                    // drop down trigger click
                    drop_down.prev($a).off('click');
                    drop_down.prev($a).parents($li).siblings($li).removeClass(list_items_active);
                    drop_down.prev($a).parents($li).siblings($li).find($li).removeClass(list_items_active);
                    //drop_down.prev($a).parents($li).siblings($li).find(drop_down).hide(0);
                    //noinspection JSValidateTypes
                    drop_down.prev($a).parent($li).find($li).removeClass(list_items_active);
                    //noinspection JSValidateTypes
                    //drop_down.prev($a).parent($li).find(drop_down).hide(0);
                    drop_down.parent($li).removeClass(list_items_active);
                    //drop_down.hide(0);

                    // drop down trigger hover
                    drop_down.parent($li).off('mouseenter mouseleave');

                    // search bar
                    var searchBarIconMobile = $this.find('#verticalMenuSearchIconMobile');
                    searchBarIcon.add(searchBarIconMobile).find('.fa-search').stop(true, true).show(0);
                    searchBarIcon.add(searchBarIconMobile).find('.fa-close').stop(true, true).hide(0);
                    searchBarContainer.hide(0).css('paddingLeft', '');
                    searchBarIcon.add(searchBarIconMobile).off('click');

                    // outside click close menu
                    $(document).off('click');

                    // auto hide
                    $this.off('mouseenter mouseleave');
                    clearTimeout(auto_hide);
                    clearTimeout(auto_hide_drop_down);
                    clearTimeout(auto_hide_search_bar);

                };

                //------------------------------------------------------------------------------------------- media query function
                Canvas.prototype.Media_Query = function (query, queryMatch) {

                    var $this_media = this;

                    // media query match function
                    queryMatch = function () {

                        // check if the responsive is true
                        if (settings.responsive === true) {
                            // check if the media query match
                            if (!query.matches) {

                                // desktop mode settings
                                //console.log('desktop');
                                $this_media.Destroy();
                                $this_media.Menu_Bar_show(true);
                                $this_media.Menu_Fixed(true);
                                $this_media.Mobile_Collapse(true);
                                $this_media.User_Profile(true);
                                $this_media.Custom_Scroll_Bar(true);
                                $this_media.Drop_Down_Trigger_Click(true);
                                $this_media.Drop_Down_Trigger_Hover(true);
                                $this_media.Search_Bar(true);
                                $this_media.Outside_Click_Hide(true);
                                $this_media.Auto_Hide(true);

                            } else {

                                // mobile mode settings
                                //console.log('mobile');
                                $this_media.Destroy();
                                $this_media.Menu_Bar_show(false);
                                $this_media.Menu_Fixed(false);
                                $this_media.Mobile_Collapse(false);
                                $this_media.User_Profile(false);
                                $this_media.Custom_Scroll_Bar(false);
                                $this_media.Drop_Down_Trigger_Click(false);
                                $this_media.Drop_Down_Trigger_Hover(false);
                                $this_media.Search_Bar(false);
                                $this_media.Outside_Click_Hide(false);
                                $this_media.Auto_Hide(false);

                            }
                        }

                        // if responsive is not true
                        else {

                            // desktop mode settings work if responsive off
                            //console.log('desktop');
                            $this_media.Destroy();
                            $this_media.Menu_Bar_show(true);
                            $this_media.Menu_Fixed(true);
                            $this_media.Mobile_Collapse(true);
                            $this_media.User_Profile(true);
                            $this_media.Custom_Scroll_Bar(true);
                            $this_media.Drop_Down_Trigger_Click(true);
                            $this_media.Drop_Down_Trigger_Hover(true);
                            $this_media.Search_Bar(true);
                            $this_media.Outside_Click_Hide(true);
                            $this_media.Auto_Hide(true);

                        }
                    };

                    // check if the responsive false then change the media query max size
                    if (settings.responsive === false) {

                        // media query max size set to 1px
                        settings.media_query_width = 1;

                    }

                    // media query max width 767px
                    //console.log(settings.media_query_width);
                    query = window.matchMedia("(max-width: " + settings.media_query_width + "px");

                    // call media query match function
                    queryMatch(query);

                    // call media query match function on screen resize
                    query.addListener(queryMatch);
                };

                // return class
                return Canvas;

            }());

            $object = new Canvas();

            // call functions
            $object.Media_Query();
            $object.Menu_Responsive();
            $object.Transparent_Menu();
            $object.Drop_Down_Indicator();

        });
    };
}(jQuery));

//--------------------------------------------------------------------------- initialize the menu with plugin options
var verticalMenuOption;

jQuery(document).ready(function ($) {

    'use strict';
    // variables
    var menuTransparent, menuCollapseDefaultTitle, $menuAutoSpeed, $dropDownAutoSpeed;

    // auto hide drop down option
    $dropDownAutoSpeed = verticalMenuOption.auto_hide_drop_down_on === 'false' ? undefined : parseInt(verticalMenuOption.auto_hide_drop_down_speed, 10);

    // auto hide menu option
    $menuAutoSpeed = verticalMenuOption.auto_hide_on === 'false' ? undefined : parseInt(verticalMenuOption.auto_hide_menu_speed, 10);

    // menu transparent option
    menuTransparent = parseFloat(verticalMenuOption.transparent) === 0 ? undefined : parseFloat(verticalMenuOption.transparent);

    // mobile view collapse title
    menuCollapseDefaultTitle = verticalMenuOption.collapse_title === '' ? 'MENU' : verticalMenuOption.collapse_title;

    $('#verticalMenu').verticalMenu({
        menu_bar_show                 : verticalMenuOption.menu_bar_show === 'true',                     //- This option show the menu bar. Options (true) or (false)
        menu_bar_show_speed           : parseInt(verticalMenuOption.menu_bar_show_speed, 10),            //- This is menu bar show and hide speed. Speed in milliseconds
        menu_bar_effect               : verticalMenuOption.menu_bar_effect,                              //- This option used for change the menu show effects. Total 6 effects (slide), (blind), (drop), (fade), (fold), (puff).
        outside_click_hide_menu       : verticalMenuOption.outside_click_hide_menu === 'true',           //- This option used for hide the showing menu bar when click outside the menu. Options (true) or (false). Note: This option works if (menu_bar_show) option true. or below option (auto_hide_menu_speed) not work if this option true.
        auto_hide_menu_speed          : $menuAutoSpeed,                                                  //- This option used for auto hide the menu bar. Option used integer value or value in milliseconds. Note: This option not work if above option (outside_click_hide_menu) true. Or set option to (undefined) disable the auto hide.
        drop_down_trigger             : verticalMenuOption.drop_down_trigger,                            //- drop down trigger change. options (click) or (hover)
        drop_down_showing_speed       : parseInt(verticalMenuOption.drop_down_showing_speed, 10),        //- drop down showing or hiding speed. Speed in milliseconds
        drop_down_auto_hide           : $dropDownAutoSpeed,                                              //- This option used for auto hide the drop down
        outside_click_hide_dropDown   : verticalMenuOption.outside_click_hide_dropDown === 'true',       //- This option used for hide the showing drop downs when click outside the menu . Options (true) or (false)
        hide_others_dropDowns_on_click: verticalMenuOption.hide_others_dropDowns_on_click === 'true',    //- This option used for hide the other showing drop downs when click on current drop down. Options (true) or (false)
        fixed_menu                    : true,                                                            //- This option fixed the menu top left side of the screen. Options (true) or (false)
        user_profile_show             : verticalMenuOption.user_profile_show === 'true',                 //- This option show the user profile. Options (true) or (false)
        transparent                   : menuTransparent,                                                 //- This option used for transparent the menu. Option Value in integer (0 to 1) or undefined to disable the transparent. Example (0.5), (0.8) etc.
        scroll_bar_always_hide        : verticalMenuOption.scroll_bar_always_hide === 'false',           //- This option used for always hide the scroll bar. Options (true) or (false).
        scroll_bar_auto_hide          : verticalMenuOption.scroll_bar_auto_hide === 'true',              //- This option used for auto hide the scroll bar. Options (true) or (false).
        scroll_amount                 : parseInt(verticalMenuOption.scroll_amount, 10),                  //- This options used for scrolling amount. Options in integer value.
        scroll_bar_button_show        : verticalMenuOption.scroll_bar_button_show === 'true',            //- This option used for show the scroll bar arrow up and down button. option (true) or (false).
        scroll_bar_auto_expand        : verticalMenuOption.scroll_bar_auto_expand === 'true',            //- This option used for auto expand the scroll bar on mouse hover. option (true) or (false).
        responsive                    : verticalMenuOption.responsive === 'true',                        //- This option make menu responsive or not. Options (true) or (false). Note: mobiles settings not work if this option false.
        search_bar_show               : verticalMenuOption.search_bar_show === 'true',                   //- This option used for show or hide the search bar
        // mobile mode settings
        mobile                        : {
            fixed_menu       : verticalMenuOption.fixed_menu_mobile === 'false',                         //- This option fixed the menu top left side of the screen. Options (true) or (false)
            user_profile_show: verticalMenuOption.user_profile_show_mobile === 'false',                  //- This option show the user profile. Options (true) or (false)
            collapse         : verticalMenuOption.collapse_mobile === 'true',                            //- This option hide the menu on mobile mode or click to show the menu on mobile mode. Options (true) or (false)
            collapse_title   : '<a href="' + verticalMenuOption.collapse_url + '">' + menuCollapseDefaultTitle + '</a>',  //- This is collapse title
            search_bar_show  : verticalMenuOption.search_bar_show_mobile === 'true'                      //- This option used for show or hide the search bar on mobile view
        }
    });

});